"""
This module provides some predefined palettes.
"""
from ..conv import hex2rgb

__all__ = [
    'brand_palettes'
]


brand_palettes = { 
'20-mule-team-borax-logo-colors': hex2rgb(['#EB2027','#5A471B']),
'2000-flushes-logo-colors': hex2rgb(['#22256C','#FF290C','#F3F42A','#4870B6','#34B0D2']),
'2019-fifa-womens-world-cup-logo-colors': hex2rgb(['#00B5ED','#23207C','#D6000A','#F08C01','#FDDB00']),
'24-hour-fitness-color-codes': hex2rgb(['#0068B3','#EE2E24','#FFFFFF']),
'2go-group-logo-colors': hex2rgb(['#EC0C8C']),
'3m-red-logo-colors': hex2rgb(['#F11523']),
'3way-international-logistics-logo-colors': hex2rgb(['#2D84B6','#656253']),
'7-eleven-colors': hex2rgb(['#F4811F','#ED2525','#008062']),
'7up-color-codes': hex2rgb(['#00452A','#00A363','#E9E9E9','#E36C52','#E52520','#B11B18','#FFFFFF']),
'9x-media-logo-colors': hex2rgb(['#02ABF0']),
'a-f-c-bournemouth-logo-colors': hex2rgb(['#000000','#FFFFFF','#C91318','#CEBA95','#FDE4C5']),
'a-mark-precious-metals-logo-colors': hex2rgb(['#2B4295','#BCC3E5','#000000']),
'aalborg-portland-logo-colors': hex2rgb(['#910023','#404244']),
'aave-colors': hex2rgb(['#B6509E','#2EBAC6']),
'abbott-laboratories-blue-logo-colors': hex2rgb(['#0095DA']),
'abhibus-logo-colors': hex2rgb(['#C22126','#551615']),
'abn-andhra-jyothi-logo-colors': hex2rgb(['#4BADD2','#724371','#A261A1','#F4DD59']),
'acc-asia-cup-logo-colors': hex2rgb(['#BF1F08','#1B2D79','#626263']),
'accenture-colors': hex2rgb(['#A100FF','#000000']),
'accorhotels-logo-colors': hex2rgb(['#E29C16','#12283B']),
'acer-color-codes': hex2rgb(['#83B81A']),
'acer-company-logo-old-colors': hex2rgb(['#005961']),
'acer-inc-logo-colors': hex2rgb(['#83B81A']),
'acko-general-insurance-logo-colors': hex2rgb(['#582CDB','#0BCF00']),
'act-fibernet-colors': hex2rgb(['#E9171C','#EF343A','#DAFA3C','#080808']),
'adata-colors': hex2rgb(['#04338E','#C70027','#8F1E22','#9E4394','#475AA7','#00A0E9','#42A732','#EEE800','#EF7A00']),
'adelaide-brighton-cement-logo-colors': hex2rgb(['#134779']),
'adelaide-football-club-logo-colors': hex2rgb(['#002B5C','#004B8D','#32619C','#FFFFFF','#FED102','#E21937']),
'adobe-acrobat-logo-colors': hex2rgb(['#F40F02']),
'adobe-after-effects-colors': hex2rgb(['#CF96FD','#393665']),
'adobe-audition-colors': hex2rgb(['#5CF3EA','#3C4D69']),
'adobe-colors': hex2rgb(['#FA0C00']),
'adobe-dreamweaver-colors': hex2rgb(['#89EF08','#3D5136']),
'adobe-encore-colors': hex2rgb(['#9DAFF7','#3D3571']),
'adobe-fireworks-colors': hex2rgb(['#E3E40A','#484728']),
'adobe-flash-builder-colors': hex2rgb(['#F67B2B','#62341D']),
'adobe-flash-colors': hex2rgb(['#CF302A','#5E3134']),
'adobe-indesign-colors': hex2rgb(['#E749A0','#562F44']),
'adobe-lightroom-colors': hex2rgb(['#B4D6E0','#2D3246']),
'adobe-logo-colors': hex2rgb(['#ED2224','#2D2E2D']),
'adobe-photoshop-colors': hex2rgb(['#001E36','#31A8FF']),
'adobe-prelude-colors': hex2rgb(['#6DC8E5','#313564']),
'adobe-primiere-pro-colors': hex2rgb(['#DB76FA','#523A5C']),
'adobe-spark-logo-colors': hex2rgb(['#FFDA00','#262000']),
'adobe-speedgrade-colors': hex2rgb(['#2DD0CD','#354A67']),
'adp-colors': hex2rgb(['#EE2722']),
'advance-auto-parts-logo-colors': hex2rgb(['#B6121B','#FFCF06','#FFFFFF','#000000']),
'aek-larnaca-fc-logo-colors': hex2rgb(['#017947','#F6EF1E']),
'aeropostale-color-codes': hex2rgb(['#CF0A2C']),
'aes-corporation-logo-colors': hex2rgb(['#80CC28','#466D12','#0573AC','#013353']),
'aflac-logo-colors': hex2rgb(['#00A5E6','#0068A7','#FAB25A','#F88C00','#054C86']),
'african-wildlife-foundation-awf-lo-colors': hex2rgb(['#4B3E36','#72635A','#9B8B83']),
'afropython-logo-colors': hex2rgb(['#913A0D','#DA691A']),
'agco-logo-colors': hex2rgb(['#C41230','#231F20']),
'aig-blue-colors': hex2rgb(['#00A3E7']),
'air-berlin-airlines-logo-colors': hex2rgb(['#CC2234']),
'air-canada-airlines-logo-colors': hex2rgb(['#D82F2E','#000000']),
'air-france-airlines-logo-colors': hex2rgb(['#002157','#F71D25','#931116']),
'air-india-express-logo-colors': hex2rgb(['#E41B47']),
'air-products-chemicals-logo-colors': hex2rgb(['#009A49']),
'air-wick-logo-colors': hex2rgb(['#478D41','#88AF3F','#017E40','#FCE544','#F5720C']),
'airbnb-colors': hex2rgb(['#FF585D']),
'aircel-ltd-logo-colors': hex2rgb(['#183883','#DA251C']),
'akmenes-cementas-logo-colors': hex2rgb(['#6C7674','#92C02D']),
'albertsons-logo-colors': hex2rgb(['#0051A1','#009FE3']),
'alcoa-logo-colors': hex2rgb(['#1450A1']),
'aldi-color-codes': hex2rgb(['#001E5E','#1FC4F4','#E11921','#F37D1E','#FABF11','#FFFFFF']),
'alexa-internet-logo-colors': hex2rgb(['#4677EF','#2540AF','#FFFFFF','#363636']),
'alexa-website-colors': hex2rgb(['#233D53','#064B73','#F9F3E6','#FA532E']),
'algolia-logo-colors': hex2rgb(['#5468FF','#FFFFFF']),
'algorand-colors': hex2rgb(['#000000']),
'alibaba-colors': hex2rgb(['#FF6A00','#000000']),
'alienware-colors': hex2rgb(['#000000']),
'allegiant-air-logo-colors': hex2rgb(['#02569B','#FFFFFF','#FBCE21','#FF9801']),
'alliance-data-systems-logo-colors': hex2rgb(['#E51635','#000000','#808080']),
'allianz-colors': hex2rgb(['#003781']),
'ally-financial-logo-colors': hex2rgb(['#50104A','#000000']),
'alphabet-colors': hex2rgb(['#ED1C24']),
'alphabet-inc-red-colors': hex2rgb(['#F01716']),
'altice-colors': hex2rgb(['#000000','#FFFFFF']),
'amazon-alexa-logo-colors': hex2rgb(['#252021','#31C4F3']),
'amazon-app-colors': hex2rgb(['#000000','#CEA968','#E4C083','#08AAE3','#2DBFF8']),
'amazon-app-old-colors': hex2rgb(['#020202','#FF9900','#146EB4']),
'amazon-color-codes': hex2rgb(['#FF9900','#000000']),
'amazon-orange-blue-colors': hex2rgb(['#FF9900','#146EB4']),
'amazon-prime-blue-logo-colors': hex2rgb(['#00A8E1']),
'amazon-prime-logo-green-colors': hex2rgb(['#7BAA40']),
'amazon-web-services-logo-colors': hex2rgb(['#252F3E','#FF9900']),
'ambuja-cements-logo-colors': hex2rgb(['#3C4089','#FBB33C','#FDD941']),
'ambuja-cements-logo-colors-2': hex2rgb(['#3C4089','#FBB33C','#FDD941']),
'amd-colors': hex2rgb(['#000000']),
'ameren-logo-colors': hex2rgb(['#35962B','#E62021','#000000']),
'american-eagle-color-codes': hex2rgb(['#000000']),
'american-express-colors': hex2rgb(['#016FD0']),
'american-family-insurance-group-logo-colors': hex2rgb(['#B80A34','#0E5994']),
'american-financial-group-logo-colors': hex2rgb(['#E31B23','#002664']),
'american-ninja-warrior-logo-colors': hex2rgb(['#284C88','#FFFFFF','#D8282B']),
'americinn-logo-colors': hex2rgb(['#B73537','#00497A']),
'amerisourcebergen-logo-colors': hex2rgb(['#00509D','#231F20']),
'amgen-blue-logo-colors': hex2rgb(['#1C60A7']),
'amphenol-logo-colors': hex2rgb(['#25509D']),
'amul-red-logo-colors': hex2rgb(['#FC0600']),
'amys-kitchen-logo-colors-2': hex2rgb(['#498850']),
'anaconda-logo-colors': hex2rgb(['#3EB049']),
'anadarko-petroleum-logo-blue-colors': hex2rgb(['#003399']),
'analog-devices-colors': hex2rgb(['#231F20']),
'anchor-colors': hex2rgb(['#5000B9']),
'andeavor-logo-colors': hex2rgb(['#6200B4','#515459']),
'andhra-bank-colors': hex2rgb(['#ED1C24','#005BAB']),
'android-brand-colors': hex2rgb(['#3DDC84']),
'android-green-colors': hex2rgb(['#32DE84']),
'android-new-logo-colors': hex2rgb(['#000000','#32DE84']),
'angularjs-colors': hex2rgb(['#B52E31','#000000']),
'anheuser-busch-inbev-logo-colors': hex2rgb(['#331D0C','#971B1E','#E02124','#F7951D','#FFF200','#E1E1E1']),
'anheuser-busch-logo-colors': hex2rgb(['#FFFF99','#F9BC06','#E83124','#8D2B1A','#11110F']),
'anhui-conch-cement-logo-colors': hex2rgb(['#241E20','#ED1B24']),
'animal-planet-logo-colors': hex2rgb(['#0074FF','#000000']),
'anixter-international-logo-colors': hex2rgb(['#818285']),
'anorthosis-famagusta-fc-logo-colors': hex2rgb(['#0055A5','#EF4035','#FFFFFF','#E7BC30']),
'anthem-blue-logo-colors': hex2rgb(['#0077C6']),
'anydesk-logo-colors': hex2rgb(['#EF443B','#000000']),
'aol-red-blue-colors': hex2rgb(['#FF0B00','#00C4FF']),
'apoel-fc-logo-colors': hex2rgb(['#A29061','#004690','#009AE1','#FFFFFF','#FED547','#E5A321']),
'apple-color-codes': hex2rgb(['#000000','#A3AAAE']),
'apple-inc-logo-gray-colors': hex2rgb(['#7D7D7D']),
'apple-iphone-colors': hex2rgb(['#000000','#9BB5CE','#5C5B57','#F9E5C9','#F5F5F0','#505F4E','#A50011','#F9F3EE','#171E27','#215E7C','#FAE0D8','#364935','#4C4A46','#F1F2ED','#FEEDD8','#2E4755','#043458','#E1F8DC','#201D24','#FBF7F4','#E23636','#B8AFE6','#4E5851','#EBEBE3','#535150','#FAD7BD','#D1CDDA','#FFE681','#AEE1CD','#1F2020','#F9F6EF','#BA0C2E','#5EB0E5','#F9F6EF','#1F2020','#F3D060','#EE7762','#A22B2A','#1F2020','#F5DDC5','#E4E4E2','#E4E4E2','#25282A','#E4E4E2','#25282A','#F5DDC5','#1F2020','#E4E4E2','#DFCCB7','#E6C7C2']),
'apple-notes-colors': hex2rgb(['#FFD52E','#F9F9F9','#E5E5E5']),
'apple-podcasts-app-icon-2017-colors': hex2rgb(['#D56DFB','#B150E2','#872EC4']),
'apple-rainbow-logo-colors': hex2rgb(['#5EBD3E','#FFB900','#F78200','#E23838','#973999','#009CDF']),
'apple-safari-logo-colors': hex2rgb(['#006CFF','#0FB5EE','#00D3F9','#FF5251','#CC1111','#9F9F9F']),
'applebees-logo-colors': hex2rgb(['#FF0D00','#B30838','#FFFFFF','#4B711C','#E4E86F','#A6B857']),
'applied-materials-logo-colors': hex2rgb(['#569CBE']),
'aramark-logo-colors': hex2rgb(['#211F20','#EB2034']),
'ararat-cement-logo-colors': hex2rgb(['#0060A7','#FFD35D']),
'arbys-color-codes': hex2rgb(['#D71921']),
'archer-daniels-midland-logo-colors': hex2rgb(['#004993','#00AA4B']),
'arctic-circle-logo-colors': hex2rgb(['#006BB8','#FEFEFE','#E63841']),
'arianespace-logo-colors': hex2rgb(['#007BC4','#000000']),
'ariel-detergent-logo-colors': hex2rgb(['#016533','#B7CE28','#E7EAA7','#E2091E']),
'arizona-cardinals-logo-colors': hex2rgb(['#99213E','#FFB700','#000000']),
'arizona-state-university-colors': hex2rgb(['#990033','#FFB310']),
'armor-all-logo-colors': hex2rgb(['#221E20','#F9851A','#FFF329']),
'arriva-danmark-blues-colors': hex2rgb(['#004D73','#00334E','#007FBD','#DBEBFA']),
'arrow-dctv-colors': hex2rgb(['#339933','#336633','#003300','#333333']),
'arrow-logo-colors': hex2rgb(['#415A68','#A99A6F']),
'arthur-color-codes': hex2rgb(['#FF0000','#000000']),
'arthur-logo-colors': hex2rgb(['#FD1812','#204E9C','#EEE93B','#4E8DC3','#F5B324','#000000']),
'asana-colors': hex2rgb(['#F06A6A','#000000']),
'asbury-automotive-group-logo-colors': hex2rgb(['#D91E18','#000000']),
'ascena-retail-group-logo-colors': hex2rgb(['#79BDE9','#A1A1A5']),
'asda-logo-colors': hex2rgb(['#78BE21']),
'asda-logo-green-colors': hex2rgb(['#78BE20']),
'asendia-logo-colors': hex2rgb(['#FFF000','#211E1E']),
'asia-airfreight-terminal-aat-logo-colors': hex2rgb(['#20318D','#F8AE27','#101010']),
'asia-cement-corporation-logo-colors': hex2rgb(['#FF002A','#5D5E61']),
'asian-football-confederation-afc-l-colors': hex2rgb(['#002395','#FFC72C']),
'asian-paints-official-logo-colors': hex2rgb(['#F03F35','#FDBA3D','#310E5F','#A893CB']),
'assassins-creed-logo-colors': hex2rgb(['#2D2C2E','#C7C8CA','#C1232C']),
'assist-america-logo-colors': hex2rgb(['#8A2035','#FFFFFF']),
'associated-banc-corp-logo-colors': hex2rgb(['#00A43B','#075719']),
'associated-cement-companies-acc-lo-colors': hex2rgb(['#EE3425']),
'association-of-tennis-professionals-colors': hex2rgb(['#002865','#00AFF0']),
'assurant-logo-colors': hex2rgb(['#F9A61A','#0070B8','#00B034','#797979']),
'asus-color-codes': hex2rgb(['#000000']),
'atlanta-braves-mlb-logo-colors': hex2rgb(['#13274F','#CE1141','#E7A801']),
'atlanta-falcons-logo-colors': hex2rgb(['#A9162D','#000000','#FFFFFF','#A5ACAF']),
'atlanta-reign-owl-logo-colors': hex2rgb(['#C4C4C4','#323232','#910F1B']),
'atria-convergence-technologies-act-colors': hex2rgb(['#E52D47']),
'att-color-codes': hex2rgb(['#00A8E0','#000000']),
'au-bon-pain-logo-colors': hex2rgb(['#FFB12B']),
'audi-colors': hex2rgb(['#000000']),
'august-schell-brewing-color-codes': hex2rgb(['#D9272E','#CEA052','#000000','#0D223F','#FFFFFF']),
'auntie-annes-logo-colors': hex2rgb(['#0056A3','#FFFFFF','#EAAC02','#E38E00']),
'auto-owners-insurance-logo-blue-colors': hex2rgb(['#084477']),
'autoliv-logo-colors': hex2rgb(['#002D6B','#D8D8D8','#8C8C8C','#000000']),
'autonation-logo-colors': hex2rgb(['#E88BB3','#191919']),
'autozone-logo-colors': hex2rgb(['#F38021','#D62C27']),
'avalanche-colors': hex2rgb(['#E84142','#FFFFFF']),
'avast-colors': hex2rgb(['#FF7800','#04121A','#FFFFFF']),
'avery-dennison-logo-colors': hex2rgb(['#EE3E34','#231F20']),
'avery-dennison-logo-red-colors': hex2rgb(['#D80024']),
'avery-logo-colors': hex2rgb(['#EB0029','#0033A0']),
'avira-colors': hex2rgb(['#D40000','#FFFFFF']),
'avis-budget-group-logo-colors': hex2rgb(['#EB184D','#214092','#FF7513']),
'aw-canada-logo-colors': hex2rgb(['#F16632','#523022']),
'aw-root-beer-color-codes': hex2rgb(['#4F2400','#D28816','#F15D22','#FFFFFF']),
'axalta-coating-systems-logo-colors': hex2rgb(['#D91C2B']),
'axis-bank-colors': hex2rgb(['#AE275F','#EB1165']),
'axis-bank-logo-maroon-colors': hex2rgb(['#800000']),
'b-m-logo-colors': hex2rgb(['#0058A5','#F5991F']),
'back-in-summer-colors': hex2rgb(['#C2DABE','#FEFADE','#E8CCAE']),
'baidu-colors': hex2rgb(['#DE0F17','#2529D8']),
'baja-fresh-colors': hex2rgb(['#5FBC4A','#FAF9FB','#FCD00B','#7FB25D']),
'baja-fresh-red-and-green-logo-colors': hex2rgb(['#02A15F','#EF3125','#FFFFFF','#231F20']),
'baja-fresh-red-logo-colors': hex2rgb(['#F02D20']),
'bajaj-auto-logo-blue-colors': hex2rgb(['#004DA8']),
'baker-hughes-logo-colors': hex2rgb(['#005AA9','#1B1B1F']),
'baltimore-orioles-mlb-logo-colors': hex2rgb(['#DF4400','#FFFFFF','#000000','#B5B6B8']),
'baltimore-ravens-logo-colors': hex2rgb(['#241075','#BC9428','#C8032B','#FFFFFF','#000000']),
'bandhan-bank-logo-colors': hex2rgb(['#A71E1F','#EF3B23','#0A3152']),
'bank-of-america-logo-colors': hex2rgb(['#0065B3','#E61030']),
'bank-of-india-boi-logo-colors': hex2rgb(['#017DC7','#FA7F22','#F33F26']),
'bank-of-new-york-mellon-logo-colors': hex2rgb(['#4F4C4D','#A7A5A6','#B07E25','#A49668']),
'banorte-logo-colors': hex2rgb(['#EF2945','#684D3D']),
'banorte-website-colors': hex2rgb(['#EC0029','#F5F5F5','#C7C9C9','#6A6867']),
'banyan-tree-holdings-logo-colors': hex2rgb(['#018458','#000000']),
'barbie-colors': hex2rgb(['#E21683']),
'barburrito-red-logo-colors': hex2rgb(['#D20B21']),
'barclays-logo-colors': hex2rgb(['#00AFE9']),
'baskin-robbins-colors': hex2rgb(['#005EA6','#DE5B9E']),
'baxter-international-logo-colors': hex2rgb(['#252969']),
'bayer-04-leverkusen-logo-colors': hex2rgb(['#E32221','#F3E500','#1A171B','#FBFBFB']),
'bayer-logo-colors': hex2rgb(['#56D500','#00314E','#01BEFF']),
'baylor-university-colors': hex2rgb(['#003015','#FFBC19']),
'bbmg-logo-colors': hex2rgb(['#CE131D']),
'bc-lions-colors': hex2rgb(['#F1551D','#000000']),
'becton-dickinson-logo-colors': hex2rgb(['#F07822','#194890']),
'bellisio-foods-logo-colors': hex2rgb(['#221E1F','#FFFFFF','#718035']),
'benjamin-moore-paints-logo-colors': hex2rgb(['#CD163F','#FFFFFF','#001641']),
'bennetts-logo-colors': hex2rgb(['#B1000B']),
'bennetts-logo-colors-2': hex2rgb(['#B1000B']),
'benq-violet-colors': hex2rgb(['#492083']),
'berger-paints-colors': hex2rgb(['#086CB7','#2C225F','#E21D26','#EB73A3','#FFFABC','#0F8040']),
'berkshire-hathaway-blue-colors': hex2rgb(['#2D2D94']),
'berry-global-group-logo-colors': hex2rgb(['#0057B8','#CEDC00','#A7A8AA','#E56A54','#7BAFD4']),
'best-western-logo-blue-colors': hex2rgb(['#1E407C']),
'bharat-electronics-limited-bel-log-colors': hex2rgb(['#00AEEF','#000000']),
'bharat-petroleum-logo-colors': hex2rgb(['#007BC9','#FFE000']),
'bharti-airtel-logo-red-colors': hex2rgb(['#FF0000']),
'bharti-airtel-logo-red-colors-2': hex2rgb(['#FF0000']),
'bhim-logo-colors': hex2rgb(['#FF7909','#018B3D']),
'bhushan-steel-logo-colors': hex2rgb(['#000000','#00AEEF']),
'big-bazaar-logo-colors': hex2rgb(['#FA7D07','#033665']),
'big-gay-ice-cream-logo-colors': hex2rgb(['#FDFD09','#82FD00','#FD0000','#FE7600','#3EFFFA','#FC01FC']),
'bigrock-logo-colors': hex2rgb(['#616868','#D8D8D9','#231F20','#F58220']),
'biotechdesk-peace-sign-colors': hex2rgb(['#EE1C25','#005BAB','#FEB811','#00A651']),
'bira-91-logo-colors': hex2rgb(['#F61B2E','#000000']),
'birla-institute-of-technology-and-sc-colors': hex2rgb(['#5CCAE8','#2B2B88','#B78A2D','#FFE275','#CF2027']),
'birla-sun-life-insurance-logo-colors': hex2rgb(['#FFCA00','#630A04','#D01645']),
'bisleri-colors': hex2rgb(['#00B3A1']),
'bkids-logo-colors': hex2rgb(['#009DDC','#FFFFFF','#9FCF67','#FFD205','#F68428']),
'bkids-logo-colors-2': hex2rgb(['#009DDC','#FFFFFF','#9FCF67','#FFD205','#F68428']),
'blender-logo-colors': hex2rgb(['#265787','#EA7600','#FFFFFF']),
'blimpie-logo-colors': hex2rgb(['#73994A','#FFFFFF','#FCD962']),
'blogger-colors': hex2rgb(['#FF5722']),
'blue-star-logo-colors': hex2rgb(['#094D9C']),
'bluehost-logo-colors': hex2rgb(['#0075FA']),
'blues-clues-logo-colors': hex2rgb(['#004A8F','#006B96','#00AEEF']),
'bmo-harris-bank-logo-colors': hex2rgb(['#0079C1','#ED1D24','#FFFFFF']),
'bmw-colors': hex2rgb(['#6F6F6F','#0166B1','#FFFFFF']),
'bmw-m-colors': hex2rgb(['#81C4FF','#16588E','#E7222E']),
'bob-the-builder-logo-colors': hex2rgb(['#FFCA02','#D91E26','#024CA1','#070045']),
'boeing-blue-colors': hex2rgb(['#1A409F']),
'booster-juice-colors': hex2rgb(['#000000','#4B1659','#EDCBC8','#E087B1','#B8184D']),
'boots-blue-logo-colors': hex2rgb(['#184290']),
'bootstrap-logo-colors': hex2rgb(['#080135','#602C50']),
'bootstrap-old-logo-purple-colors': hex2rgb(['#553C7B']),
'borgwarner-logo-colors': hex2rgb(['#204080']),
'boston-celtics-logo-colors': hex2rgb(['#008347','#BB9852','#000000','#FFFFFF','#FAB383','#A8342E']),
'boston-market-logo-colors': hex2rgb(['#D01501','#FFFFFF','#000000']),
'boston-red-sox-mlb-logo-colors': hex2rgb(['#C62033','#FFFFFF','#052755']),
'boston-scientific-logo-colors': hex2rgb(['#07457E']),
'bounty-logo-colors': hex2rgb(['#6CCFF6','#2BB34B','#74C043','#C4D82D','#FFEC00','#EF4323']),
'brand-factory-logo-colors': hex2rgb(['#ED1B24','#FFFFFF','#2B2724','#F4792B']),
'braums-logo-colors': hex2rgb(['#9F2443','#373F83','#E9D684','#F1E6AC','#B11F73']),
'bricks-camera-app-colors': hex2rgb(['#5D19FF','#F8E71D']),
'bright-side-logo-colors': hex2rgb(['#FFCC35','#000000']),
'brighton-hove-albion-f-c-logo-colors': hex2rgb(['#005DAA','#FFFFFF','#FDB913']),
'brisbane-broncos-logo-colors': hex2rgb(['#760036','#FABF16']),
'brisbane-lions-logo-colors': hex2rgb(['#0054A4','#FFFFFF','#FFE19B','#FDBF57','#A50044','#7C003E']),
'british-airways-logo-colors': hex2rgb(['#2A5C9A','#CF1C06']),
'british-airways-website-colors': hex2rgb(['#075AAA','#EB2226','#01295C','#B9CFED','#EFE9E5','#A7A9AC']),
'british-american-tobacco-logo-colors': hex2rgb(['#FAB41E','#17468B']),
'british-petroleum-bp-logo-colors': hex2rgb(['#009900','#99CC00','#FFFF00','#FFFFFF']),
'bud-light-logo-colors': hex2rgb(['#37388E','#2B95E1']),
'buffalo-bills-logo-colors': hex2rgb(['#C8023A','#00308F']),
'builders-firstsource-logo-colors': hex2rgb(['#ED1D24','#292670']),
'bumble-logo-colors': hex2rgb(['#FFCB37']),
'bumbo-logo-colors': hex2rgb(['#E1058B','#FFFFFF']),
'bumbo-logo-colors-2': hex2rgb(['#E1058B','#FFFFFF']),
'burberry-colors-scottish-tartan-colors': hex2rgb(['#A70100','#513819','#956226','#B8A081','#747674','#0D100E']),
'burberry-grey-tartan-print-colors': hex2rgb(['#484848','#696969','#353535','#040404','#A41F26']),
'burger-chef-logo-1972-1978-colors': hex2rgb(['#FD0100','#FB9B37','#0000C1','#000109']),
'burger-chef-logo-1978-1996-colors': hex2rgb(['#F88000','#9E000C']),
'burger-chef-logo-colors': hex2rgb(['#F93800','#FDFECF','#FFFFFF','#05B1DD']),
'burger-chef-logo-colors-2': hex2rgb(['#F93800','#FDFECF','#FFFFFF','#05B1DD']),
'burger-king-logo-1969-1994-colors': hex2rgb(['#E0A000','#E1391E']),
'burger-king-logo-1994-1999-colors': hex2rgb(['#F28A21','#EC242D']),
'burnley-f-c-logo-colors': hex2rgb(['#97D9F5','#F5F014','#F8B319','#630F33','#14141E']),
'c-h-robinson-worldwide-logo-colors': hex2rgb(['#0078AE','#000000','#F57B20']),
'cadbury-colors': hex2rgb(['#B9861F','#482683']),
'cadbury-dairy-milk-logo-colors': hex2rgb(['#2D006B','#9C7E46','#CBB386','#FEFEFE']),
'cadbury-purple-violet-colors': hex2rgb(['#482683']),
'cadwaladers-ice-cream-logo-colors': hex2rgb(['#131F2B']),
'cafe-coffee-day-colors': hex2rgb(['#FF0200','#8E3BB1']),
'cafe-coffee-day-new-red-colors': hex2rgb(['#D61820']),
'cakephp-logo-colors': hex2rgb(['#323233','#C92735']),
'calgon-logo-colors': hex2rgb(['#00B9F0','#003D82','#000040']),
'calpine-logo-colors': hex2rgb(['#00639E']),
'campbell-soup-logo-colors': hex2rgb(['#BE1923','#CB9A26']),
'campbells-logo-red-colors': hex2rgb(['#C31229']),
'canada-post-logo-colors': hex2rgb(['#004A8E','#FFFFFF','#D3200D']),
'canberra-raiders-logo-colors': hex2rgb(['#000000','#00AC5B','#C3D941','#F3D5BA','#FFFFFF','#A1BECF']),
'canterbury-bankstown-bulldogs-logo-colors': hex2rgb(['#231F20','#A7A9AC','#FFFFFF','#0054A4']),
'canva-colors': hex2rgb(['#01C3CC','#2A89DA','#7D2AE7']),
'capital-one-financial-logo-colors': hex2rgb(['#004879','#D22E1E']),
'captain-ds-logo-colors': hex2rgb(['#1E76B5','#5392CB','#89BFDF','#E5F0F6','#CB6C2D']),
'captain-submarine-colors': hex2rgb(['#EF3B43','#FDFEFE','#231E1F']),
'cardiff-city-f-c-logo-colors': hex2rgb(['#0070B5','#FFFFFF','#D11524']),
'cardinal-health-logo-colors': hex2rgb(['#F34D3E','#000000']),
'cardsox-website-colors': hex2rgb(['#C33655','#E94166','#FFFFFF','#C4D3CA','#542733']),
'care-hospitals-logo-colors': hex2rgb(['#897AB9','#808285']),
'carinos-italian-logo-colors': hex2rgb(['#235E36','#ECCB61','#FFFFFF','#CB292B']),
'carls-jr-logo-colors': hex2rgb(['#FFC82C','#000000']),
'carlson-logo-colors': hex2rgb(['#8C7D70','#C7940D','#DC351C']),
'carlson-wagonlit-travel-logo-colors': hex2rgb(['#1E2A39','#EA6547']),
'carmax-logo-colors': hex2rgb(['#00529F','#FFD520']),
'carolina-panthers-logo-colors': hex2rgb(['#0084CD','#000000','#BFC0BF']),
'carrows-logo-colors': hex2rgb(['#FFD503','#C00827']),
'cartoon-network-colors': hex2rgb(['#00AEEF','#ED008C','#FFF000','#000000']),
'carvel-ice-cream-logo-colors': hex2rgb(['#DD042C']),
'carvel-ice-cream-old-logo-colors': hex2rgb(['#0091E7','#FFFFFF','#FBDB2F','#C1035B']),
'caseys-general-stores-logo-colors': hex2rgb(['#231F20','#AE6219','#ED1B2D','#FFE01A']),
'caspian-pools-colors': hex2rgb(['#5AB5B0','#004870','#84704B']),
'cbre-group-logo-colors': hex2rgb(['#006A4D']),
'cdw-logo-colors': hex2rgb(['#CC0000']),
'celgene-logo-colors': hex2rgb(['#1C3B7E']),
'cement-corporation-of-india-limited-colors': hex2rgb(['#FEFEFE','#2B2A29']),
'centene-corporation-logo-colors': hex2rgb(['#024069','#98958C']),
'centerpoint-energy-logo-colors': hex2rgb(['#0098D6','#231F20']),
'charles-schwab-logo-blue-colors': hex2rgb(['#009EDC']),
'charter-communications-logo-colors': hex2rgb(['#00629B','#787878']),
'chaseblue-loans-colors': hex2rgb(['#1CC1E1','#0F4B93']),
'checkers-logo-colors': hex2rgb(['#C4281D','#E53024','#A8AAAC','#FFFFFF','#FFFD03']),
'cheer-logo-blue-colors': hex2rgb(['#160B4D']),
'chelsea-f-c-colors-2': hex2rgb(['#034694','#6A7AB5','#D1D3D4','#FFFFFF','#DBA111','#ED1C23']),
'chesapeake-energy-logo-colors': hex2rgb(['#004479','#8FC637','#706F74']),
'chevron-logo-colors': hex2rgb(['#0054A4','#198FCB','#E20D19','#A31127']),
'chicago-bears-logo-colors': hex2rgb(['#0A162B','#CA3700']),
'chicago-cubs-mlb-logo-colors': hex2rgb(['#0E3386','#FFFFFF','#CC3433']),
'chicago-white-sox-mlb-logo-colors': hex2rgb(['#231F20','#FFFFFF','#C4CDD3']),
'chillis-logo-colors': hex2rgb(['#EE2722','#FFFFFF','#559821']),
'china-mobile-colors': hex2rgb(['#8CC518','#0084CE']),
'choice-hotels-logo-colors': hex2rgb(['#E26812','#FFC52D','#5E5745']),
'chore-boy-logo-colors': hex2rgb(['#00AEEF','#006FBB','#FFF100','#ED1C24','#FCD2C1','#C7EAFC']),
'chupa-chups-logo-colors': hex2rgb(['#D0073E','#FFF400','#A79352']),
'cigna-logo-colors': hex2rgb(['#0080C9','#FA9800','#52BB40']),
'cillit-bang-logo-colors': hex2rgb(['#553788','#081171','#78CEEB','#EC210E']),
'cincinnati-bengals-logo-colors': hex2rgb(['#FE4E00','#000000']),
'cincinnati-reds-mlb-logo-colors': hex2rgb(['#C6011F','#FFFFFF','#000000']),
'cinema-tv-logo-colors': hex2rgb(['#DC2026','#7E1616','#FFFEAD','#FCC252','#FDFCFA','#C0C1C1']),
'cinnabon-logo-colors': hex2rgb(['#121E48','#FFFFFF','#67CBC9']),
'citigroup-logo-colors': hex2rgb(['#003A72','#DB230B']),
'cleveland-browns-logo-colors': hex2rgb(['#FF3A00','#FFFFFF','#311D00']),
'cleveland-clinic-logo-colors': hex2rgb(['#0468CD','#006633','#525148']),
'cleveland-indians-mlb-logo-colors': hex2rgb(['#E31937','#FFFFFF']),
'clorox-logo-colors': hex2rgb(['#419639','#0082C8']),
'cloudnine-hospitals-logo-colors': hex2rgb(['#904A8E','#EA3994']),
'club-brugge-kv-logo-colors': hex2rgb(['#000000','#FFFFFF','#D9A500','#0078BB']),
'cms-energy-logo-colors': hex2rgb(['#0094D2','#7BBD45']),
'coast-hotels-logo-colors': hex2rgb(['#C83A82','#6E2F8F','#636366']),
'coca-cola-color-codes': hex2rgb(['#E61D2B']),
'codeigniter-official-brand-red-colors': hex2rgb(['#DD4814']),
'codepen-colors': hex2rgb(['#0EBEFF','#47CF73','#AE63E4','#FCD000','#FF3C41','#76DAFF']),
'coffee-time-logo-colors': hex2rgb(['#A92336','#301812','#F5F12E']),
'cold-stone-creamery-logo-colors': hex2rgb(['#C50A2A','#FFFFFF','#BE8901','#FBC00D','#9A2B2E','#AA4746']),
'colgate-palmolive-logo-colors': hex2rgb(['#007AC2','#000000']),
'color-switch-game-colors': hex2rgb(['#272727','#FAE100','#900DFF','#FF0181','#32DBF0']),
'comcast-logo-colors': hex2rgb(['#FCB712','#F37020','#CD004D','#6460AC','#008AD2','#0CB14B']),
'comfort-fabric-softener-logo-colors': hex2rgb(['#11155F']),
'compaq-red-colors': hex2rgb(['#C50A27']),
'computer-sciences-corporation-csc-colors': hex2rgb(['#E70021']),
'conagra-brands-logo-colors': hex2rgb(['#171516','#E44130','#71B842','#0776B3']),
'condor-flugdienst-airlines-logo-colors': hex2rgb(['#FBAB18','#6F757A']),
'connexxion-colors': hex2rgb(['#D2EA32','#016773']),
'conocophillips-red-logo-colors': hex2rgb(['#F23C3C']),
'consolidated-graphics-group-colors': hex2rgb(['#B0B67A','#1E5152']),
'constellation-brands-logo-colors': hex2rgb(['#0076BF','#021D5B']),
'cook-out-restaurant-logo-colors': hex2rgb(['#000000','#C4141C']),
'coolhaus-logo-colors': hex2rgb(['#000000','#ED127B']),
'cooper-tire-rubber-company-logo-colors': hex2rgb(['#18468B']),
'coors-brewing-company-logo-colors': hex2rgb(['#000D48','#FFFFFF','#95969A']),
'country-buffet-logo-colors': hex2rgb(['#003060']),
'country-style-logo-colors': hex2rgb(['#EE7522','#FFFFFF','#5F462B']),
'cracker-barrel-logo-colors': hex2rgb(['#551505','#F9A812']),
'cronulla-sutherland-sharks-logo-colors': hex2rgb(['#00A9D8','#000000']),
'crowne-plaza-logo-colors': hex2rgb(['#830051','#FFFFFF']),
'crunch-fitness-color-codes': hex2rgb(['#D20224','#FF9247','#FFFFFF']),
'crystal-palace-f-c-logo-colors': hex2rgb(['#1B458F','#C4122E','#FFFFFF','#A7A5A6']),
'cst-brands-logo-colors': hex2rgb(['#009DE1','#233C98']),
'culvers-blue-logo-colors': hex2rgb(['#005599']),
'd2h-logo-colors': hex2rgb(['#42206D','#6D3691']),
'dafont-logo-colors': hex2rgb(['#CC0000']),
'dairy-queen-color-codes': hex2rgb(['#EE3E42','#007AC1','#F9AA53','#FFFFFF']),
'dalian-port-pda-company-logo-colors': hex2rgb(['#000884','#CE4008','#6C8CE6','#000000']),
'dallas-cowboys-logo-colors': hex2rgb(['#002145','#FFFFFF']),
'dallas-fuel-owl-logo-colors': hex2rgb(['#0072CE','#032340','#9EA2A2']),
'dangal-tv-logo-colors': hex2rgb(['#726016','#C2A734','#FFD01E','#9F1E56','#5B0029']),
'dangote-cement-logo-colors': hex2rgb(['#171D64','#F0513A']),
'darden-restaurants-logo-colors': hex2rgb(['#8B181B','#231F20']),
'dasani-blue-logo-colors': hex2rgb(['#193C96']),
'datsun-logo-colors': hex2rgb(['#363C44','#DADFE5','#FFFFFF','#A1A0D2','#4454A2','#2C3974']),
'davita-logo-colors': hex2rgb(['#093870','#F8AA12']),
'dawn-logo-colors': hex2rgb(['#ADB6BD','#003794','#00B8F6']),
'dbs-bank-logo-colors': hex2rgb(['#FF3333','#000000']),
'dc-comics-logo-colors': hex2rgb(['#0476F2']),
'dcb-bank-logo-colors': hex2rgb(['#26358F']),
'dean-foods-logo-colors': hex2rgb(['#52B12F','#006F5F','#1C4E9D']),
'debain-linux-logo-colors': hex2rgb(['#D80150','#000000']),
'decred-colors': hex2rgb(['#2970FF','#2ED6A1','#091440']),
'del-taco-color-codes': hex2rgb(['#EF3340']),
'delhi-public-school-dps-logo-colors': hex2rgb(['#075133']),
'dell-color-codes': hex2rgb(['#007DB8']),
'deloitte-colors': hex2rgb(['#86BC24','#000000']),
'delta-airlines-logo-colors': hex2rgb(['#E3132C','#9B1631','#003268']),
'denver-broncos-logo-colors': hex2rgb(['#002145','#FFFFFF','#FE4E00']),
'depend-logo-colors': hex2rgb(['#006329','#137533','#6AA848','#2A9644','#FFFFFF','#B6B8BA']),
'depend-logo-colors-2': hex2rgb(['#006329','#137533','#6AA848','#2A9644','#FFFFFF','#B6B8BA']),
'detroit-lions-logo-colors': hex2rgb(['#0075B8','#FFFFFF','#B0B7BC']),
'detroit-tigers-mlb-logo-colors': hex2rgb(['#0C2C56']),
'dettol-logo-colors': hex2rgb(['#8DC32D','#D0E135','#0A1B79']),
'deviantart-logo-colors': hex2rgb(['#05CC46','#FFFFFF']),
'deviantart-web-site-colors': hex2rgb(['#465B4D','#3D4E42','#7E907F','#D4DFD1','#DBE3D6','#5EAC74']),
'dfinity-colors': hex2rgb(['#0E031F','#29ABE2','#F15A24','#FBB03B','#522785','#ED1E79']),
'dhanlaxmi-bank-logo-colors': hex2rgb(['#550044']),
'dhl-colors': hex2rgb(['#D2002E','#FFCC01']),
'dicks-sporting-goods-logo-colors': hex2rgb(['#2E7E6A','#006150','#74B096','#F89B34']),
'diet-coke-can-colors': hex2rgb(['#000000','#F70000','#E6E6E5','#A7A7A7','#7D7C7C']),
'digibyte-colors': hex2rgb(['#0066CC','#002352','#FFFFFF']),
'dineout-app-colors': hex2rgb(['#FA5754']),
'discord-colors': hex2rgb(['#5865F2']),
'discover-financial-services-logo-colors': hex2rgb(['#000000','#E55C20','#F9A021']),
'discovery-communications-logo-colors': hex2rgb(['#221E1F','#1575C5']),
'dish-network-color-codes': hex2rgb(['#EC1944']),
'disney-fireworks-intro-colors': hex2rgb(['#1738B7','#3340DB','#504DF4','#DE5BF8','#EFE8FF','#A76BFE']),
'disney-pictures-blue-intro-colors': hex2rgb(['#113CCF','#BFF5FD','#FFFFFF']),
'disney-xd-logo-colors': hex2rgb(['#08EE59']),
'disney-xd-old-logo-colors': hex2rgb(['#243E65','#B5DB17']),
'dji-colors': hex2rgb(['#000000','#FFFFFF']),
'dollar-general-logo-colors': hex2rgb(['#CACBCC','#1C1B1B','#FFF000']),
'dollar-tree-logo-colors': hex2rgb(['#1A1819','#007F3A','#59BA29']),
'domino-colors': hex2rgb(['#14A057','#055882']),
'dominos-color-codes': hex2rgb(['#E31837','#006491','#FFFFFF']),
'don-pablos-purple-logo-colors': hex2rgb(['#951F97']),
'don-pablos-purple-logo-colors-2': hex2rgb(['#951F97']),
'donut-king-logo-colors': hex2rgb(['#ED008C','#781C7D']),
'donut-king-old-logo-colors': hex2rgb(['#EC008C','#FFFFFF','#43BCDC','#FFF200']),
'doordash-logo-colors': hex2rgb(['#FF3008']),
'dora-the-explorer-color-codes': hex2rgb(['#844CA4','#0F73B8','#1D4591','#E84622','#439F33','#F13EA1']),
'dora-the-explorer-logo-colors': hex2rgb(['#773B96','#1268AE','#E74323','#3E9A34','#F13EA1','#1D4591']),
'dove-blue-logo-colors': hex2rgb(['#09094A']),
'dover-logo-colors': hex2rgb(['#004B8D']),
'dow-chemicals-red-colors': hex2rgb(['#F23C3C']),
'downy-logo-blue-colors': hex2rgb(['#002159']),
'doxa-katokopias-fc-logo-colors': hex2rgb(['#154416','#C6A531']),
'dpd-group-logo-colors': hex2rgb(['#BB0033','#DC0032','#424143']),
'dr-oetker-logo-colors': hex2rgb(['#E30714','#FFFFFF','#26348B']),
'dr-pepper-color-codes': hex2rgb(['#D31145','#8C002A','#000000','#FFFFFF']),
'dr-pepper-snapple-group-logo-colors': hex2rgb(['#5C6F7B','#87CADE','#97002E']),
'dribbble-web-site-colors': hex2rgb(['#E94C88','#FBFBFB','#F4F4F4','#333333','#252525']),
'dropbox-logo-colors': hex2rgb(['#0060FF','#000000']),
'drupal-blue-logo-colors': hex2rgb(['#25AAE1']),
'duckduckgo-logo-colors': hex2rgb(['#E37151','#5B9E4D','#F1A031','#00278E','#FFFFFF','#333333']),
'duke-energy-logo-colors': hex2rgb(['#14BCD9','#005986','#50BB40']),
'duke-java-mascot-colors': hex2rgb(['#000000','#FFFFFF','#ED1D25','#F14C4D','#FAB9A8']),
'dunkin-donuts-color-codes': hex2rgb(['#FE6D01','#F40290']),
'dunzo-logo-colors': hex2rgb(['#00FFA4','#4AAFF7']),
'duolingo-colors': hex2rgb(['#58CC02','#89E219','#4B4B4B','#FFFFFF','#B66E28','#F49000','#FFC200','#FFDE00']),
'dupont-red-logo-colors': hex2rgb(['#E61031']),
'dusit-thani-group-logo-blue-colors': hex2rgb(['#004B94']),
'dutch-bros-coffee-colors': hex2rgb(['#156299','#FFFFFF','#F8E316','#DA262E']),
'dynamo-dresden-logo-colors': hex2rgb(['#93000E','#FDFDFD','#F3AC26','#060604']),
'dyson-colors': hex2rgb(['#000000']),
'e-trade-logo-colors': hex2rgb(['#000000','#6633CC','#99CC00']),
'earthbound-farm-logo-colors': hex2rgb(['#F0B323','#000000']),
'earthbound-farm-logo-colors-2': hex2rgb(['#F0B323','#000000']),
'eastman-chemical-logo-red-colors': hex2rgb(['#ED1B2F']),
'easybuy-logo-colors': hex2rgb(['#E3000F','#00963F']),
'ebay-color-codes': hex2rgb(['#E53238','#0064D2','#F5AF02','#86B817']),
'echo-music-award-colors': hex2rgb(['#B39C4C','#4E2578']),
'eclipse-software-logo-colors': hex2rgb(['#F7941E','#2C2255','#443583']),
'ecolab-logo-blue-colors': hex2rgb(['#0098CC']),
'edge-colors': hex2rgb(['#66EDA8','#0E4B75']),
'eicher-motors-logo-colors': hex2rgb(['#808080','#FF0000']),
'el-taco-tote-logo-colors': hex2rgb(['#00A652','#251F22','#F4DA2D','#E7362C','#FFFFFF','#660913']),
'election-commission-of-india-eci-l-colors': hex2rgb(['#231F20','#F58220','#FFFFFF','#4DB848','#939598']),
'elevation-burger-logo-colors': hex2rgb(['#223B7D','#FFFFFF','#1D9ED9']),
'eli-lilly-red-logo-colors': hex2rgb(['#F01716']),
'elrond-colors': hex2rgb(['#000000','#FFFFFF']),
'emcor-group-logo-colors': hex2rgb(['#018287']),
'emerson-electric-logo-colors': hex2rgb(['#004487','#285F9A','#E5E6E7','#A1A3A5']),
'employees-provident-fund-orga-colors': hex2rgb(['#010177','#268DFF','#FF0101']),
'england-national-rugby-league-team-l-colors': hex2rgb(['#B31F1D','#162545']),
'england-national-rugby-union-team-lo-colors': hex2rgb(['#B5282F','#E52E33','#009E6A','#00643F','#25292A']),
'entergy-logo-colors': hex2rgb(['#E21F26','#231F20']),
'enterprise-products-blue-logo-colors': hex2rgb(['#173F74']),
'entertainment-and-sports-programming-colors': hex2rgb(['#E52534']),
'envato-logo-colors': hex2rgb(['#79B34C','#141614']),
'enzyme-colors': hex2rgb(['#6852ED','#01CABE','#010202']),
'eog-resources-logo-colors': hex2rgb(['#EE3124','#000000']),
'epictions-logo-colors': hex2rgb(['#333333','#FF2152']),
'erie-insurance-group-logo-colors': hex2rgb(['#005FAC','#000000']),
'ermis-aradippou-fc-logo-colors': hex2rgb(['#D92226','#FFFFFF','#070D09']),
'espn-colors': hex2rgb(['#E52534']),
'ethnikos-achna-fc-logo-colors': hex2rgb(['#0A4A9E','#FFFFFF']),
'etoro-colors': hex2rgb(['#6AAE22']),
'etsy-logo-colors': hex2rgb(['#F56400']),
'eurocement-group-logo-colors': hex2rgb(['#A7B6BF','#F7941E']),
'evaneos-logo-colors': hex2rgb(['#11726B','#FFFFFF']),
'evergreen-industrial-services-logo-colors': hex2rgb(['#27A063','#BAB9B5']),
'evernote-colors': hex2rgb(['#00A82D','#000000']),
'eversource-energy-logo-colors': hex2rgb(['#000000','#00ADEE','#00B040','#007748']),
'everton-f-c-logo-colors': hex2rgb(['#274488','#FFFFFF']),
'evian-water-color-codes': hex2rgb(['#54565A','#E50043']),
'excel-color-codes': hex2rgb(['#10793F','#185C37','#21A366','#33C481','#FFFFFF']),
'exelon-logo-colors': hex2rgb(['#8FBB33','#1D9C44','#FA9D1B','#F45614','#105FAE','#0D8ACF']),
'exodus-colors': hex2rgb(['#00BFFF','#6619FF','#1F2133']),
'expedia-colors': hex2rgb(['#202843','#FEC84C']),
'expeditors-international-of-washingt-colors': hex2rgb(['#050708','#EF3E35']),
'express-scripts-blue-colors': hex2rgb(['#0660A7']),
'extended-stay-america-logo-colors': hex2rgb(['#A9D48A','#72BF44','#52443C']),
'extended-stay-america-logo-colors-2': hex2rgb(['#A9D48A','#72BF44','#52443C']),
'exxonmobil-red-colors': hex2rgb(['#F01523']),
'ezoic-green-colors': hex2rgb(['#5FA624']),
'f-n-b-corporation-logo-colors': hex2rgb(['#003876','#A80532']),
'f-secure-logo-colors': hex2rgb(['#E62A33']),
'faceapp-icon-colors': hex2rgb(['#724BCC','#56C2E6','#F3246C','#FEDF12']),
'facebook-colors': hex2rgb(['#0165E1','#17A9FD']),
'facebook-new-blue-logo-colors': hex2rgb(['#1778F2']),
'facebook-web-blue-and-gray-colors': hex2rgb(['#4267B3','#E9EBEE','#90949C','#616771']),
'fairfield-inn-suites-logo-colors': hex2rgb(['#105290']),
'fairtrade-international-flo-logo-colors': hex2rgb(['#CDD42A','#00B0DB','#010202']),
'fandom-logo-colors': hex2rgb(['#002B2E','#00D6D9']),
'fantom-colors': hex2rgb(['#1969FF']),
'farmers-insurance-exchange-logo-colors': hex2rgb(['#1C428B','#A6C3E9','#E11631','#A20F30']),
'fatburger-logo-colors': hex2rgb(['#FFF796','#E03A3E']),
'fc-admira-wacker-modling-logo-colors': hex2rgb(['#000000','#DA2128','#EDC74A']),
'fc-alashkert-logo-colors': hex2rgb(['#333333','#EBEA59','#F3F3AA']),
'fc-ararat-yerevan-logo-colors': hex2rgb(['#00009C','#FF0000','#FFFFFF','#424A52']),
'fc-augsburg-logo-colors': hex2rgb(['#FFD42E','#BA3733','#46714D','#FFFFFF','#221F1F']),
'fc-banants-logo-colors': hex2rgb(['#1C449C']),
'fc-bate-borisov-logo-colors': hex2rgb(['#D7B56D','#333E8F','#FFFFFF','#FECC00','#4FD5FD']),
'fc-bayern-munich-logo-colors': hex2rgb(['#0066B2','#FFFFFF','#DC052D']),
'fc-dinamo-minsk-logo-colors': hex2rgb(['#FFFE00','#FFFFFF','#1F77B4']),
'fc-dnepr-mogilev-logo-colors': hex2rgb(['#F9D518','#FFFFFF','#364E9C']),
'fc-dunav-ruse-logo-colors': hex2rgb(['#146DAF','#FFFFFF']),
'fc-dynamo-brest-logo-colors': hex2rgb(['#003866','#FFFFFF']),
'fc-encamp-logo-colors': hex2rgb(['#0000FF','#009A00','#212284','#FF3400']),
'fc-erzgebirge-aue-logo-colors': hex2rgb(['#ECC200','#5D3B85','#FFFFFF','#3BA1CE']),
'fc-gandzasar-kapan-logo-colors': hex2rgb(['#2C2E80','#B8BAB5','#DADBD9','#C7AB6E','#193B6F','#000000']),
'fc-gomel-logo-colors': hex2rgb(['#00A651','#FFFFFF','#FFF200','#231F20']),
'fc-gorodeya-logo-colors': hex2rgb(['#24211D','#F0E900','#E24100']),
'fc-ingolstadt-04-logo-colors': hex2rgb(['#D71920','#FFFFFF','#231F20']),
'fc-isloch-minsk-raion-logo-colors': hex2rgb(['#1E1A17','#545F65','#D1D1D1','#ABA8A9','#181818']),
'fc-kamza-logo-colors': hex2rgb(['#1F183F','#1860AA']),
'fc-luch-minsk-2012-logo-colors': hex2rgb(['#243E94','#DA251D','#F3F2F2','#1F1A17']),
'fc-lusitanos-logo-colors': hex2rgb(['#000000','#FFDA06','#E92414','#FFFFFF','#1459A8']),
'fc-minsk-logo-colors': hex2rgb(['#0391DB','#DA241B','#28156E','#1E1A19','#DDDCDA']),
'fc-neman-grodno-logo-colors': hex2rgb(['#FCD719','#00A94C','#9F4231','#FFFFFF','#000000']),
'fc-nurnberg-logo-colors': hex2rgb(['#AD1732','#FFFFFF']),
'fc-pyunik-logo-colors': hex2rgb(['#DEAE24','#AA5F27','#17719B','#115473','#FFFFFF']),
'fc-red-bull-salzburg-logo-colors': hex2rgb(['#0F2D5B','#091D3C','#FFFFFF','#D3D3D3','#E41349','#FDD205']),
'fc-santa-coloma-logo-colors': hex2rgb(['#000000','#370E81','#F5DA10','#EE1317']),
'fc-schalke-04-logo-colors': hex2rgb(['#004D9D','#FFFFFF']),
'fc-shakhtyor-soligorsk-logo-colors': hex2rgb(['#000000','#FFDE00','#FFFFFF','#C5161D','#C2CDD3']),
'fc-slutsk-logo-colors': hex2rgb(['#0041D0','#0F8307','#E81E24','#E7E104','#C1C1C2']),
'fc-smolevichi-logo-colors': hex2rgb(['#FFF12E','#CB2229','#2D72B3','#FFFFFF','#000000']),
'fc-st-pauli-logo-colors': hex2rgb(['#EC1B24','#000000','#FFFFFF']),
'fc-torpedo-belaz-zhodino-logo-colors': hex2rgb(['#171717','#FFFFFF','#EF7F2D']),
'fc-vitebsk-logo-colors': hex2rgb(['#034EA2','#FFFFFF']),
'federal-bank-logo-colors': hex2rgb(['#00488E','#F7A800']),
'fedora-linux-logo-colors': hex2rgb(['#0B57A4','#FFFFFF','#072C61']),
'fels-naptha-logo-colors': hex2rgb(['#0A4436','#A8142C']),
'femsa-red-logo-colors': hex2rgb(['#9D2736']),
'fidelity-national-financial-logo-colors': hex2rgb(['#002C6D','#6BA2C1']),
'fidelity-national-information-servic-colors': hex2rgb(['#E5F1D4','#CFE5AE','#B9D989','#A3CF62','#8DC63F']),
'fifth-third-bancorp-logo-colors': hex2rgb(['#509236','#164399']),
'filezilla-icon-colors': hex2rgb(['#BF0000','#8F0000']),
'firebase-colors': hex2rgb(['#FFA611','#F5820D','#FFCB2B']),
'firefox-logo-colors': hex2rgb(['#E66000','#FF9500','#FFCB00','#00539F','#0095DD','#331E54']),
'firehouse-subs-logo-colors': hex2rgb(['#E03A3E','#FFFFFF','#231F20','#FDB925']),
'firstenergy-logo-colors': hex2rgb(['#231F20','#1A5DAD']),
'fis-colors': hex2rgb(['#4BCD3E']),
'fitbit-colors': hex2rgb(['#00B0B9','#002A3A']),
'fk-austria-wien-logo-colors': hex2rgb(['#441678','#FFFFFF','#AE9A64']),
'fk-borac-banja-luka-logo-colors': hex2rgb(['#C4A662','#D93730','#FFFFFF','#18559A']),
'fk-dukla-prague-logo-colors': hex2rgb(['#221F21','#C6993B','#DD332F','#3085A4']),
'fk-jablonec-logo-colors': hex2rgb(['#07852F','#FFFFFF','#000000']),
'fk-krupa-logo-colors': hex2rgb(['#E7D96E','#0064AB','#E10623','#FFFFFF','#E10623']),
'fk-kukesi-logo-colors': hex2rgb(['#010101','#06295F','#EEEFF0']),
'fk-mlada-boleslav-logo-colors': hex2rgb(['#084064','#146AA4','#288CBA','#AFDFF1','#CAB253']),
'fk-mladost-doboj-kakanj-logo-colors': hex2rgb(['#FD0000','#F9D027','#F4F4F4','#3A3637']),
'fk-partizani-tirana-logo-colors': hex2rgb(['#FF0000','#EBB803','#FFE600']),
'fk-sarajevo-logo-colors': hex2rgb(['#5D0D10','#FFFFFF']),
'fk-sloboda-tuzla-logo-colors': hex2rgb(['#D4AB69','#EC1B21','#2A2A2A']),
'fk-teplice-logo-colors': hex2rgb(['#FEE501','#FFFFFF','#0410C3']),
'flaticon-web-colors': hex2rgb(['#072238','#263E51','#4EE787','#16D298']),
'flattr-logo-colors': hex2rgb(['#EC6B27','#F29124','#F7AD20','#A3CF3B','#82BD33','#6DB02F']),
'flickr-logo-colors': hex2rgb(['#0063DC','#FF0084']),
'flipkart-plus-colors': hex2rgb(['#1F74BA','#F7E200','#F09120','#FFFFFF']),
'florida-mayhem-owl-logo-colors': hex2rgb(['#FEDB00','#AF272F','#000000']),
'flow-colors': hex2rgb(['#00EF8B','#FFFFFF','#000000']),
'flydubai-airlines-logo-colors': hex2rgb(['#FF8200','#006496']),
'follr-logo-colors': hex2rgb(['#3DCEFF','#EF7400','#FF3197','#557DBD','#ACC100']),
'food-lion-logo-colors': hex2rgb(['#000000','#005695']),
'foodpanda-color-codes': hex2rgb(['#D70F64']),
'football-association-of-malaysia-fa-colors': hex2rgb(['#000000','#FFF200']),
'ford-motor-logo-colors': hex2rgb(['#003478','#FFFFFF']),
'formula-409-logo-colors': hex2rgb(['#7EAEDE','#263997','#100261','#F5E700']),
'formula-one-old-logo-colors': hex2rgb(['#000000','#E22420']),
'fortive-colors': hex2rgb(['#64B65B','#000000']),
'fox-life-blue-colors': hex2rgb(['#20D2FF','#521F61']),
'fox-life-colors': hex2rgb(['#01DCA2','#521F61']),
'fox-life-orange-colors': hex2rgb(['#FF521D','#521F61']),
'freddie-mac-logo-colors': hex2rgb(['#009BE4','#FFFFFF','#6CB516']),
'freedos-logo-colors': hex2rgb(['#000000','#BFCFE7']),
'freepik-website-colors': hex2rgb(['#12191D','#1C262D','#26363E','#7C98A9','#F4F4F4','#0072E9']),
'freeport-mcmoran-logo-colors': hex2rgb(['#00AEEF','#000000']),
'fremantle-football-club-logo-colors': hex2rgb(['#250553','#FFFFFF','#A4AEB5']),
'freshii-green-logo-colors': hex2rgb(['#007B3E']),
'friendlys-logo-red-colors': hex2rgb(['#E32524']),
'frontier-airlines-logo-colors': hex2rgb(['#248168','#9F9A98']),
'frosch-usa-logo-colors': hex2rgb(['#009835','#E50005']),
'frost-bank-web-site-colors': hex2rgb(['#00273E','#02699C','#50B6F2','#FFFFFF','#F4F4F4','#D6D6D6']),
'ftx-colors': hex2rgb(['#11A9BC','#33BBC7','#84D6D7','#000000']),
'g-playstore-colors': hex2rgb(['#5AEDD5','#3089AC','#9DE7AD','#FEC476','#D1406D','#A336B4']),
'g-suite-logo-colors': hex2rgb(['#737373']),
'gabala-fk-logo-colors': hex2rgb(['#010101','#FDFDFD','#D23138']),
'gamestop-logo-colors': hex2rgb(['#000000','#FD0000']),
'gap-color-codes': hex2rgb(['#000000']),
'garageband-app-icon-2017-colors': hex2rgb(['#ED3342','#F57A37','#FABF2F']),
'garnier-logo-colors': hex2rgb(['#407E06','#BCCF11','#042B19']),
'garuda-logo-colors': hex2rgb(['#484848','#002561','#2F6F7E']),
'gateway-colors': hex2rgb(['#040404','#039A0F']),
'gateway-distriparks-logo-colors': hex2rgb(['#FD0003','#003F7D']),
'gatorade-color-codes': hex2rgb(['#000000','#E52B38','#F5A748']),
'gci-graphics-colors': hex2rgb(['#00A2E3','#023A5D','#221E1F','#949599']),
'ge-colors': hex2rgb(['#3B73B9','#FFFFFF']),
'ge-general-electric-blue-colors': hex2rgb(['#3B73B9']),
'geforce-now-colors': hex2rgb(['#76B900','#000000','#FFFFFF']),
'gem-global-entrepreneurship-movemen-colors': hex2rgb(['#E61873','#662483','#157DC1','#F39200','#94C11F','#E30613']),
'gemini-tv-logo-colors': hex2rgb(['#7B0002','#BD3908','#FA4202','#FAC306']),
'general-logistics-systems-logo-colors': hex2rgb(['#E5AF00','#FFFFFF','#1C156D']),
'general-motors-logo-colors': hex2rgb(['#194390','#5C93CC','#FFFFFF','#86C1E2','#1F3F97','#000082']),
'general-society-of-surveillance-sgs-colors': hex2rgb(['#77787B','#F36F21']),
'genuine-parts-company-logo-colors': hex2rgb(['#FDB826','#FFFFFF','#0054A3']),
'genworth-financial-logo-colors': hex2rgb(['#000000','#007DC3']),
'geotrust-logo-colors': hex2rgb(['#006BB1','#F37121']),
'germanwings-airlines-logo-colors': hex2rgb(['#760B39','#A90650','#FAB20B']),
'ghost-blogging-logo-colors': hex2rgb(['#404041','#E8E9EB','#707E86']),
'gigabyte-technology-logo-colors': hex2rgb(['#005DAA']),
'gilead-sciences-logo-colors': hex2rgb(['#C80037','#646569']),
'gillette-colors': hex2rgb(['#031A46']),
'gilson-graphics-colors': hex2rgb(['#040404','#FFCD00','#0697C4']),
'github-cat-icon-colors': hex2rgb(['#211F1F','#F4CBB2','#AD5C51','#FFFFFF','#9CDAF1','#7DBBE6']),
'github-colors': hex2rgb(['#000000']),
'glade-logo-blue-colors': hex2rgb(['#003572']),
'glass-plus-logo-colors': hex2rgb(['#E6142D','#C2000F']),
'global-cement-logo-colors': hex2rgb(['#196C8D','#C0B099']),
'global-entrepreneurship-summit-2017-colors': hex2rgb(['#D42047','#0080C7','#00AD79','#241E61']),
'global-hospitals-india-logo-colors': hex2rgb(['#17469E','#F04D23']),
'global-partners-logo-colors': hex2rgb(['#002B89','#FA4034']),
'gmail-logo-old-colors': hex2rgb(['#D44638','#B23121','#EEEEEE','#E2E2E2','#DADADA','#C6C6C6']),
'godaddy-logo-colors': hex2rgb(['#121212','#EC6D23','#FBDC2D','#3FB54F','#FFFFFF']),
'gogovan-logo-colors': hex2rgb(['#0188C0','#FFDE00']),
'gojek-logo-colors': hex2rgb(['#00AA13','#000000']),
'gold-coast-football-club-logo-colors': hex2rgb(['#FFE010','#B90A34','#E92A1F','#F15D42','#F37755','#0681C2']),
'gold-coast-titans-logo-colors': hex2rgb(['#BA8748','#FBB03F','#E0C398','#231F20','#A7A9AC','#0072AE']),
'gold-dust-washing-powder-logo-colors': hex2rgb(['#DA571F','#E0A969']),
'golden-corral-logo-colors': hex2rgb(['#FF0F01','#FFD063','#FFFCB8','#FFFEFE']),
'golden-state-warriors-logo-colors': hex2rgb(['#006BB8','#FDBA21']),
'golden-state-warriors-logo-colors-2': hex2rgb(['#006BB8','#FDBA21']),
'goldman-sachs-colors': hex2rgb(['#6B96C3','#FFFFFF']),
'goldman-sachs-logo-colors': hex2rgb(['#64A8F0']),
'golds-gym-color-codes': hex2rgb(['#FFEC00','#000000']),
'golem-network-colors': hex2rgb(['#181EA9','#404B63','#A2A3B9']),
'golfsixes-logo-colors': hex2rgb(['#0841F3','#E416FE']),
'goli-vadapav-logo-colors': hex2rgb(['#E91C23','#FFFEFE','#7FB043','#489150','#F0B21A','#482B23']),
'google-allo-yellow-colors': hex2rgb(['#FBBC05']),
'google-analytics-color-codes': hex2rgb(['#E37400','#F9AB00']),
'google-chrome-colors': hex2rgb(['#259645','#E23A2E','#FCC31E','#1A73E8','#FFFFFF']),
'google-colors': hex2rgb(['#4285F4','#DB4437','#F4B400','#0F9D58']),
'google-drive-colors': hex2rgb(['#1FA463','#FFD04B','#4688F4','#3D6EC9']),
'google-duo-blue-colors': hex2rgb(['#4285F4']),
'google-map-basic-colors': hex2rgb(['#D5D8DB','#E8E8E8','#C3ECB2','#AADAFF','#FFF2AF','#F6CF65']),
'google-map-basic-colors-2': hex2rgb(['#D5D8DB','#E8E8E8','#C3ECB2','#AADAFF','#FFF2AF','#F6CF65']),
'google-maps-logo-colors': hex2rgb(['#1EA362','#FFE047','#4A89F3','#D3D3D3','#DD4B3E','#822F2B']),
'google-pay-logo-colors': hex2rgb(['#3A81F1','#2DA94F','#FDBD00','#EA4335','#5F6368']),
'google-photos-colors': hex2rgb(['#8DC44F','#1CA45C','#FFC718','#FF9E0F','#DA483B','#4486F4']),
'google-play-games-logo-colors': hex2rgb(['#1D7C48','#FAFAFA','#00E26B','#00B359']),
'google-play-music-logo-colors': hex2rgb(['#F55A34','#FFD119','#FF8C00','#FAFAFA']),
'google-plus-red-logo-colors': hex2rgb(['#DD4B39']),
'google-search-results-colors': hex2rgb(['#006627','#1906A7','#3484F0','#808080','#545454']),
'google-spreadsheets-green-colors': hex2rgb(['#0F9D58']),
'google-stadia-logo-colors': hex2rgb(['#FC4A1F','#AC0D57']),
'gopro-color-codes': hex2rgb(['#000000','#109DD9','#075DAA','#E8E8EA']),
'graco-logo-colors': hex2rgb(['#00539F']),
'graco-logo-colors-2': hex2rgb(['#00539F']),
'graeters-logo-colors': hex2rgb(['#3E1A1A','#911034']),
'grammarly-colors': hex2rgb(['#15C39A','#4C4C4C','#FFFFFF','#0066CC','#FFCC00','#000000']),
'gravatar-colors': hex2rgb(['#1E8CBE']),
'graybar-electric-logo-colors': hex2rgb(['#231F20','#ACAEB1','#0093C9']),
'greater-western-sydney-giants-logo-colors': hex2rgb(['#F47A1A']),
'greater-western-sydney-giants-logo-colors-2': hex2rgb(['#F47A1A']),
'green-bay-packers-logo-colors': hex2rgb(['#1F3731','#FFFFFF','#FFB700']),
'green-party-of-michigan-united-stat-colors': hex2rgb(['#19421A','#508C1B']),
'greyhound-courier-express-logo-colors': hex2rgb(['#A8A8A8','#F8061F']),
'group-1-automotive-logo-colors': hex2rgb(['#C5C3C4','#E22425']),
'groupe-valentine-logo-colors': hex2rgb(['#004791','#929296','#FFFFFF','#EF2D1F']),
'groupon-colors': hex2rgb(['#53A318','#FFFFFF','#333333','#BBBCBC']),
'grupo-argos-logo-colors': hex2rgb(['#012063']),
'gst-council-logo-colors': hex2rgb(['#F37A1F','#00A652','#26538C']),
'gtmetrix-logo-colors': hex2rgb(['#3398D0','#7EB0DC','#DAE6F0']),
'guangzhou-charge-owl-logo-colors': hex2rgb(['#67A2B2','#0FEFD9','#122C42']),
'guardian-life-ins-co-of-america-lo-colors': hex2rgb(['#805020','#D2C26D']),
'gulf-air-airlines-logo-colors': hex2rgb(['#034D8E','#A29061']),
'gvk-logo-colors': hex2rgb(['#1F1A17','#DA251C','#B3261D']),
'hactl-logo-colors': hex2rgb(['#53839B','#082E7B']),
'halliburton-logo-colors': hex2rgb(['#ED171F']),
'hamburger-sv-logo-colors': hex2rgb(['#0A3F86','#FFFFFF','#000000']),
'hanesbrands-logo-colors': hex2rgb(['#ED2224','#5E1E5F']),
'hangzhou-spark-owl-logo-colors': hex2rgb(['#FB7299','#FFFFFF','#5788CE']),
'hardees-color-codes': hex2rgb(['#272526','#F0C640']),
'haribo-red-colors': hex2rgb(['#DE2108']),
'harley-davidson-colors': hex2rgb(['#FF6600','#000000','#FFFFFF']),
'harman-international-industries-logo-colors': hex2rgb(['#00A7E4','#006499']),
'harmony-colors': hex2rgb(['#04B1E7','#68F9BE','#555B68']),
'harpic-logo-colors': hex2rgb(['#EC2030']),
'harris-logo-colors': hex2rgb(['#000000','#D00A2C']),
'harveys-logo-colors': hex2rgb(['#F5821F','#002764','#000000']),
'hathway-cable-datacom-logo-colors': hex2rgb(['#19468A','#CE000C']),
'hawthorn-football-club-logo-colors': hex2rgb(['#4D2004','#FABF16','#FFFFFF','#000000']),
'hca-holdings-logo-colors': hex2rgb(['#0A1C5E','#4A99B0']),
'hcl-blue-colors': hex2rgb(['#0066AE']),
'hd-supply-holdings-logo-colors': hex2rgb(['#FBC411','#231F20']),
'hearst-communications-logo-colors': hex2rgb(['#4C76A2']),
'hearthstone-logo-colors': hex2rgb(['#73471C','#EDA115','#FCD237','#7E7463','#2C2319']),
'heidelbergcement-logo-colors': hex2rgb(['#009D57']),
'heineken-color-codes': hex2rgb(['#008200','#205527','#FF2B00','#C3C3C3']),
'heinz-beanz-blue-colors': hex2rgb(['#0095A3']),
'heinz-brand-red-green-yell-colors': hex2rgb(['#B21F29','#E82B00','#FDB700','#00B400','#262F6A','#0095A3']),
'heinz-red-colors': hex2rgb(['#C82922']),
'heinz-tomato-ketchup-logo-colors': hex2rgb(['#C82922','#CBAB5E','#008650']),
'helium-colors': hex2rgb(['#474DFF','#000000']),
'hellmann-worldwide-logistics-logo-colors': hex2rgb(['#E32119','#004C99']),
'heroku-website-colors': hex2rgb(['#C9C3E6','#6762A6']),
'hershey-logo-brown-colors': hex2rgb(['#381216']),
'hertz-global-holdings-logo-colors': hex2rgb(['#FFF400','#272425']),
'hewlett-packard-color-codes': hex2rgb(['#0096D6']),
'hewlett-packard-enterprise-colors': hex2rgb(['#00B287','#425563']),
'hey-arnold-color-codes': hex2rgb(['#FFCC00','#000000']),
'hi5-logo-orange-colors': hex2rgb(['#FF9900']),
'highfive-colors': hex2rgb(['#A26EEA','#F7AFFF','#5D70EA','#46B7FD']),
'hindustan-petroleum-logo-colors': hex2rgb(['#CE0000','#00006B']),
'hindustan-unilever-hul-logo-colors': hex2rgb(['#035597']),
'hisense-colors': hex2rgb(['#00B3AC']),
'hm-color-codes': hex2rgb(['#CC071E']),
'hnk-cibalia-logo-colors': hex2rgb(['#DC351B','#FFFFFF','#0093CA','#A7A6A5','#1F1A17']),
'hnk-hajduk-split-logo-colors': hex2rgb(['#FFC20E','#21409A','#FFFFFF','#ED1C24']),
'hnk-rijeka-logo-colors': hex2rgb(['#DDBE80','#FFFFFF','#38A1CE']),
'hobby-lobby-logo-colors': hex2rgb(['#EF4317','#1D4998']),
'holcim-logo-colors': hex2rgb(['#ED1C24','#231F20','#918F90']),
'hollyfrontier-logo-colors': hex2rgb(['#3A424A','#656C73','#00336F']),
'home-bargains-logo-colors': hex2rgb(['#9FDDF9','#EE3424']),
'home-depot-colors': hex2rgb(['#F96302','#FFFFFF']),
'homeaway-colors': hex2rgb(['#2A6EBB','#FF8A00']),
'hometown-buffet-logo-colors': hex2rgb(['#0D6B51']),
'honda-colors': hex2rgb(['#CC0000']),
'honeywell-red-logo-colors': hex2rgb(['#EE3124']),
'horizen-colors': hex2rgb(['#0E9DE5','#26DB8D','#041742']),
'hormel-foods-logo-colors': hex2rgb(['#00904C','#D2232A']),
'hostgator-logo-colors': hex2rgb(['#03324F','#27578A','#3A80BF','#FFCE4F','#FE8B58','#FB6A31']),
'hostinger-logo-colors': hex2rgb(['#674CC4']),
'hotstar-colors': hex2rgb(['#01147C','#0000FD','#06B2FF']),
'houston-outlaws-owl-logo-colors': hex2rgb(['#97D700','#FFFFFF','#000000']),
'houston-texans-team-colors': hex2rgb(['#022030','#FFFFFF','#A9162D']),
'hp-hindustan-petroleum-old-logo-colors': hex2rgb(['#EB4120','#2962AF']),
'hrg-group-logo-colors': hex2rgb(['#015571','#1B252C']),
'hrs-global-hotel-solutions-logo-colors': hex2rgb(['#062A4A','#004C81','#1C588E','#5EC6E2','#CD032C','#A6161E']),
'hsbc-bank-usa-logo-colors': hex2rgb(['#DB0011','#FFFFFF','#000000']),
'hsbc-colors': hex2rgb(['#DB0011','#000000','#FFFFFF']),
'htc-green-colors': hex2rgb(['#8CC751']),
'html5-logo-colors': hex2rgb(['#000000','#E44D26','#F16529','#EBEBEB','#FFFFFF']),
'huawei-colors': hex2rgb(['#CF0A2C','#232527']),
'huawei-logo-colors': hex2rgb(['#CF0A2C','#232527']),
'hubspot-logo-colors': hex2rgb(['#33475B','#FF7A59']),
'hubspot-logo-colors-2': hex2rgb(['#33475B','#FF7A59']),
'hubspot-old-logo-colors': hex2rgb(['#4A5B67','#FA7820']),
'huddersfield-town-a-f-c-logo-colors': hex2rgb(['#2E70BE','#10132E','#BBBABA','#FDE43C','#9D1F2A']),
'huggies-logo-colors': hex2rgb(['#E7194A']),
'huggies-logo-colors-2': hex2rgb(['#E7194A']),
'hughesnet-color-codes': hex2rgb(['#005DAC','#FFFFFF']),
'hughesnet-logo-colors': hex2rgb(['#005DAC']),
'hulu-color-codes': hex2rgb(['#1CE783']),
'humana-green-colors': hex2rgb(['#5BA908']),
'huntington-bancshares-logo-colors': hex2rgb(['#66BD29','#776F67']),
'huntington-ingalls-industries-logo-colors': hex2rgb(['#004A8D','#E5B53A']),
'huntsman-logo-colors': hex2rgb(['#982937','#02406B']),
'husd-colors': hex2rgb(['#1A61F0','#FFFFFF','#000000']),
'hy-vee-color-codes': hex2rgb(['#E2231A']),
'hyatt-logo-blue-colors': hex2rgb(['#4B77A9']),
'hyperx-colors': hex2rgb(['#E31837','#B3B3B3']),
'hyundai-colors': hex2rgb(['#003984']),
'iberia-airlines-logo-colors': hex2rgb(['#A8151C','#C11623','#DA162A','#F9CD03','#F6AF03','#E97B0D']),
'ibm-colors': hex2rgb(['#1F70C1']),
'icahn-enterprises-blue-logo-colors': hex2rgb(['#3D6699']),
'icc-cricket-world-cup-2019-logo-colors': hex2rgb(['#5F717F','#FF0045']),
'icc-mens-t20-world-cup-logo-colors': hex2rgb(['#133A75','#1C5D9C','#DA2C5A','#02A7D1','#0A0A0A']),
'icc-womens-t20-world-cup-logo-colors': hex2rgb(['#5B0220','#9F015B','#EE2364','#FDB719','#000000']),
'ice-age-logo-colors': hex2rgb(['#39BBF0','#231F20']),
'iceland-foods-logo-colors': hex2rgb(['#D2212E']),
'icici-bank-logo-colors': hex2rgb(['#B02A30','#F99D27','#005B75']),
'icon-colors': hex2rgb(['#30B7BA','#000000']),
'idea-logo-colors': hex2rgb(['#FFEF09','#056FD0','#02020D']),
'idfc-first-bank-logo-colors': hex2rgb(['#BC8CBF','#FFCB04','#F16669','#F79448']),
'ifttt-logo-colors': hex2rgb(['#33CCFF','#FF4400','#000000']),
'iheartmedia-logo-colors': hex2rgb(['#C6002B','#111820','#919395']),
'ikea-logo-color-codes': hex2rgb(['#0058AB','#FBD914']),
'illinois-tool-works-logo-colors': hex2rgb(['#6E0F1A']),
'imdb-logo-colors': hex2rgb(['#DBA506','#F2DB83','#000000']),
'in-n-out-burger-color-codes': hex2rgb(['#E02A27','#FFCB05']),
'inbox-by-gmail-logo-colors': hex2rgb(['#3357C0','#477CE3','#E3E3E3','#56C5F7','#12AEF5']),
'indeed-logo-colors': hex2rgb(['#2164F3']),
'indian-coast-guard-logo-colors': hex2rgb(['#2C5AA0','#D4AA00']),
'indian-oil-corporation-logo-colors': hex2rgb(['#F37022','#FEFEFE','#02164F']),
'indian-overseas-bank-logo-colors': hex2rgb(['#013CC8']),
'indian-railway-catering-and-tourism-colors': hex2rgb(['#000075','#CCC7D2']),
'indian-space-research-organisation-colors': hex2rgb(['#F47216','#0E88D3']),
'indian-super-league-isl-logo-colors': hex2rgb(['#2C3179','#FFCE34','#EF3E3A','#6E1910']),
'indiana-pacers-logo-colors': hex2rgb(['#002962','#FDBC2D','#FFFFFF','#BFC1C3']),
'indianapolis-colts-team-colors': hex2rgb(['#002B61']),
'indusind-bank-logo-colors': hex2rgb(['#98272A']),
'infosys-colors': hex2rgb(['#3781C2']),
'instagram-color-codes': hex2rgb(['#405DE6','#5851DB','#833AB4','#C13584','#E1306C','#FD1D1D','#F56040','#F77737','#FCAF45','#FFDC80']),
'intel-colors': hex2rgb(['#0068B5','#000000']),
'inter-club-descaldes-logo-colors': hex2rgb(['#000000','#0534FE','#FEFEFE']),
'inter-milan-logo-colors': hex2rgb(['#A39261','#1266AB','#040707','#FFFFFF']),
'intercontinental-exchange-logo-colors': hex2rgb(['#73C7E8','#000000']),
'intercontinental-hotels-group-logo-colors': hex2rgb(['#D96932']),
'international-cricket-council-icc-colors': hex2rgb(['#4CCDED','#0084C7','#006A4D','#000000','#E71C23']),
'international-organization-for-stand-colors': hex2rgb(['#E30613']),
'international-yoga-day-colors': hex2rgb(['#0072BB','#03B2F1','#DABA7F','#3AB54A','#F5881F','#FDE760']),
'international-youth-conference-iyc-colors': hex2rgb(['#1A3A6D','#FAA21C','#14111C']),
'internet-explorer-10-11-colors': hex2rgb(['#1EBBEE']),
'internet-explorer-4-5-colors': hex2rgb(['#0099FF']),
'internet-explorer-6-colors': hex2rgb(['#00D4F9','#0091D6']),
'internet-explorer-7-8-colors': hex2rgb(['#000D13','#0055B2','#F5B62B','#FBD02A','#83E9FC']),
'interpublic-group-logo-colors': hex2rgb(['#83C2EC','#0B335E','#1477C6']),
'intl-fcstone-logo-colors': hex2rgb(['#003962','#0067AC','#5C86A0','#C3D2D3','#006426','#4B711D']),
'intown-suites-logo-colors': hex2rgb(['#071689','#FD8204','#00ADD9']),
'ipl-chennai-super-kings-logo-colors': hex2rgb(['#F9CD05','#F15C19','#00ADEF','#1D418C']),
'ipl-deccan-chargers-logo-colors': hex2rgb(['#425170','#021B3A','#D5D6D0','#AE0B2C','#20201E']),
'ipl-delhi-capitals-logo-colors': hex2rgb(['#2561AE','#282968','#FAAD1B','#D71921']),
'ipl-delhi-daredevils-logo-colors': hex2rgb(['#213F7D','#EDC82D','#E32A26','#C02826']),
'ipl-kings-xi-punjab-logo-colors': hex2rgb(['#ED1D24','#A7A9AC','#D7D8DA','#F9F9F9']),
'ipl-kochi-tuskers-kerala-logo-colors': hex2rgb(['#7F3F98','#03B3DC','#141006','#807F83']),
'ipl-kolkata-knight-riders-logo-colors': hex2rgb(['#F2C028','#F9E278','#3A225D','#64517C']),
'ipl-mumbai-indians-logo-colors': hex2rgb(['#F79433','#00A65D','#005FA2','#EF312F','#FFCC32']),
'ipl-pune-warriors-india-logo-colors': hex2rgb(['#000000','#FCF105','#EA4C2D','#FFFFFF','#66A24B']),
'ipl-rajasthan-royals-logo-colors': hex2rgb(['#254AA5','#CBA92B']),
'ipl-rising-pune-supergiant-logo-colors': hex2rgb(['#AB5C28','#FBCE58','#2D0E05','#9E3495','#FB2897','#FF8209']),
'ipl-royal-challengers-bangal-colors': hex2rgb(['#C9920E','#252829','#FADF8D','#E63329']),
'ipl-sunrisers-hyderabad-logo-colors': hex2rgb(['#FEDC32','#F7A721','#E3263B','#9A1C22','#352722']),
'isl-atk-football-club-logo-colors': hex2rgb(['#7B4E00','#FFDA61','#D91610','#40568F','#CFDBD7']),
'isl-bengaluru-fc-logo-colors': hex2rgb(['#EBE726','#2A479E','#FFFFFF','#EC2227','#BD2029']),
'isl-chennaiyin-fc-logo-colors': hex2rgb(['#1B4794','#FDB813','#F9ED1A','#FFFFFF']),
'isl-delhi-dynamos-fc-logo-colors': hex2rgb(['#1627A8','#FB1A46','#DCDAD6','#BB9993']),
'isl-fc-goa-logo-colors': hex2rgb(['#070F57','#FD7200','#F4EFEF']),
'isl-fc-pune-city-logo-colors': hex2rgb(['#41288D','#693D97','#F8971C','#DCDDDF','#FFFFFF']),
'isl-jamshedpur-fc-logo-colors': hex2rgb(['#2AAAE2','#114D8D','#EA2432','#FAED24','#FFFFFF']),
'isl-kerala-blasters-fc-logo-colors': hex2rgb(['#092F87','#013CA6','#F4E84E']),
'isl-mumbai-city-fc-logo-colors': hex2rgb(['#E3C38C','#FFFFFF','#092265']),
'isl-northeast-united-fc-logo-colors': hex2rgb(['#E51B24','#FFFFFF','#000000']),
'issuu-colors': hex2rgb(['#F36D5D','#5F5F5F']),
'isuzu-motors-logo-red-colors': hex2rgb(['#DA251C']),
'italcementi-logo-colors': hex2rgb(['#FCA415','#1A1411']),
'itc-limited-logo-colors': hex2rgb(['#062F62']),
'itc-logo-colors': hex2rgb(['#052E6E']),
'j-b-hunt-transport-services-logo-colors': hex2rgb(['#FFDB00','#000000']),
'j-m-smucker-logo-colors': hex2rgb(['#EF3E42','#231F20']),
'j-p-morgan-colors': hex2rgb(['#000000']),
'jabong-com-logo-colors': hex2rgb(['#F68B23','#000000']),
'jack-daniels-colors': hex2rgb(['#000000','#FFFFFF']),
'jack-in-the-box-color-codes': hex2rgb(['#E51837','#B50A37','#D0DCDB','#FFFFFF']),
'jacksonville-jaguars-team-colors': hex2rgb(['#A07A22','#D8A311','#006779']),
'jacobs-engineering-group-logo-blue-colors': hex2rgb(['#00338D']),
'jammu-kashmir-bank-logo-colors': hex2rgb(['#DE4019','#0084C4','#68B92E','#1F1A16']),
'japan-airlines-logo-colors': hex2rgb(['#C90000','#000000']),
'japan-freight-railway-company-logo-colors': hex2rgb(['#5F7F9F']),
'japan-golf-tour-logo-colors': hex2rgb(['#005130','#FFFFFF','#ECB709']),
'japan-post-holdings-logo-colors': hex2rgb(['#CC0033']),
'javascript-logo-colors': hex2rgb(['#F0DB4F','#323330']),
'jawa-moto-logo-colors': hex2rgb(['#A31D1E','#EEEAEF']),
'jcpenney-color-codes': hex2rgb(['#E71324']),
'jefferson-health-logo-colors': hex2rgb(['#152456','#57B4DA']),
'jelly-belly-logo-colors': hex2rgb(['#FA1500','#FFEF00']),
'jersey-mikes-color-codes': hex2rgb(['#134A7C','#EE3227','#FFFFFF']),
'jet-airways-logo-colors': hex2rgb(['#0F204B','#FCAE1B']),
'jetblue-airways-logo-colors': hex2rgb(['#003876']),
'jimdo-logo-colors': hex2rgb(['#00828C','#006678','#005469']),
'jimmy-johns-color-codes': hex2rgb(['#EA0029','#000000','#FFFFFF']),
'jindal-steel-and-power-jspl-logo-colors': hex2rgb(['#000000','#58595B','#F47920','#4FA941']),
'jio-logo-blue-colors-2': hex2rgb(['#005AAC']),
'jio-logo-red-colors-2': hex2rgb(['#FF0000']),
'jiosaavn-logo-colors': hex2rgb(['#2BC5B4','#2A2D36']),
'john-deere-colors': hex2rgb(['#367C2B','#FFDE00','#27251F']),
'john-lewis-logo-colors': hex2rgb(['#003B25']),
'johnson-controls-logo-colors': hex2rgb(['#00B8E0','#0399CC','#0554A3','#08338F','#29B582','#7DBA00']),
'johnson-johnson-red-colors': hex2rgb(['#D71500']),
'jollibee-logo-colors': hex2rgb(['#E0163D','#FFFFFF','#231F20']),
'jones-lang-lasalle-logo-colors': hex2rgb(['#E30613','#000000']),
'joomla-colors': hex2rgb(['#E52627','#0D6DAB','#5AA427','#FC8F30','#3B3A40']),
'joomla-logo-colors': hex2rgb(['#86BE3C','#E4B645','#C33734','#748EC4','#000000']),
'joox-colors': hex2rgb(['#00DE75','#000000']),
'joy-dishwashing-liquid-logo-colors': hex2rgb(['#0F467E','#09A6DD']),
'jquery-logo-colors': hex2rgb(['#0868AC','#131B28']),
'jsdelivr-logo-colors': hex2rgb(['#E84D3D','#FDC72E','#E09B00','#BC473A','#1D3A45']),
'jsl-s-a-logo-colors': hex2rgb(['#7C7A7A','#FFFFFF','#F71B2C']),
'jumeirah-hotel-chain-logo-colors': hex2rgb(['#957F3E','#081D61']),
'just-eat-logo-colors': hex2rgb(['#FA0129','#00AC41','#E2E71F','#2F7DE1','#7DCAEB','#FFD700']),
'just-eat-logo-red-colors': hex2rgb(['#FA0129']),
'justdial-logo-colors': hex2rgb(['#116DB6','#F26600']),
'kamineni-hospitals-logo-colors': hex2rgb(['#F71B2C','#007DB3','#A1CE4A']),
'kansas-city-chiefs-team-colors': hex2rgb(['#E60F31']),
'karnataka-bank-logo-colors': hex2rgb(['#853A93']),
'karur-vysya-bank-logo-colors': hex2rgb(['#E7E514','#00854A','#000000']),
'kaspersky-colors': hex2rgb(['#009982']),
'kava-colors': hex2rgb(['#FF564F']),
'kc-grey-logo-colors': hex2rgb(['#585F6D','#9CA0A9','#FFFFFF','#000000']),
'kelloggs-colors': hex2rgb(['#D31245']),
'kelloggs-logo-red-colors': hex2rgb(['#D50842']),
'kentucky-fried-chicken-color-codes': hex2rgb(['#F40027','#FFFFFF','#000000']),
'kerala-tourism-logo-colors': hex2rgb(['#009A4E','#FAA61A','#ED1D24','#8ED8F8','#0CB7E1','#005BAA']),
'keystone-light-color-codes': hex2rgb(['#005189','#43B4E3','#FFFFFF']),
'keyword-surfer-color-codes': hex2rgb(['#F1C385','#EF8B8B','#E65F88','#3F1658']),
'kfc-logo-1997-2006-colors': hex2rgb(['#EE1833','#154181','#FFFFFF','#FDE5B3']),
'kfc-logo-colors': hex2rgb(['#A3080B','#000000','#FFFFFF','#FFF1E2','#F5D4B7']),
'kia-motors-logo-colors': hex2rgb(['#BB162C','#7E8083']),
'kik-logo-green-colors': hex2rgb(['#61CB2B']),
'kimberly-clark-logo-colors-2': hex2rgb(['#3C93CB','#414749']),
'kinder-logo-colors': hex2rgb(['#1B1B1B','#E73E09']),
'kinder-morgan-logo-colors': hex2rgb(['#231F20','#DA3930']),
'kindred-healthcare-logo-colors': hex2rgb(['#231F20','#448BBD']),
'kingston-technology-colors': hex2rgb(['#FF0000','#000000','#FFFFFF']),
'kitkat-logo-red-colors': hex2rgb(['#EC2227']),
'kleenex-logo-colors-2': hex2rgb(['#0E59A9']),
'klm-airlines-logo-blue-colors': hex2rgb(['#00A1E4']),
'kodak-logo-yellow-red-colors': hex2rgb(['#FAB617','#E30613']),
'kohls-color-codes': hex2rgb(['#800033']),
'kool-aid-colors': hex2rgb(['#00AEEF','#0056A2','#FFFFFF']),
'korean-air-colors': hex2rgb(['#154D9E','#FFFFFF','#EE1229']),
'kotlin-colors': hex2rgb(['#E24462','#B125EA','#7F52FF','#000000']),
'kraft-foods-logo-colors': hex2rgb(['#005EB2','#2BC5F6','#F13F99','#F11716','#FFCA00','#F88101']),
'krispy-kreme-logo-colors': hex2rgb(['#CC083E','#FFFFFF','#00764F']),
'kroger-color-codes': hex2rgb(['#21409A']),
'kubuntu-linux-logo-colors': hex2rgb(['#0077C4']),
'kucoin-colors': hex2rgb(['#23AF91']),
'kuwait-airways-logo-colors': hex2rgb(['#1F2C56','#24638E']),
'kv-mechelen-logo-colors': hex2rgb(['#E9B646','#E41B13','#FFE500','#000000']),
'kyocera-colors': hex2rgb(['#DF0522','#000000']),
'l3-technologies-logo-colors': hex2rgb(['#C23A46','#000000']),
'la-fitness-color-codes': hex2rgb(['#10103E','#FCB116','#000000']),
'la-quinta-inns-suites-logo-colors': hex2rgb(['#FAE65F','#E0922D','#005033']),
'labatt-brewing-company-logo-colors': hex2rgb(['#D2AB67','#ED1C24','#164E9C']),
'laboratory-corp-of-america-logo-colors': hex2rgb(['#007DA4']),
'lacoste-color-codes': hex2rgb(['#004526','#DB0026','#000000','#FFFFFF']),
'lafargeholcim-logo-colors': hex2rgb(['#4C403B','#7B6668']),
'lakshmi-vilas-bank-colors': hex2rgb(['#ED1C24','#FFFFFF','#F47216']),
'lalamove-logo-colors': hex2rgb(['#F26722','#FEA000']),
'lam-research-colors': hex2rgb(['#005488']),
'lamborghini-logo-colors': hex2rgb(['#F7DE9F','#F9CE5C','#D8A016','#9F6B08','#040404','#282928']),
'land-olakes-logo-colors': hex2rgb(['#6EBE3B','#D7EDC1','#B9CFE1','#005581']),
'land-olakes-logo-colors-2': hex2rgb(['#6EBE3B','#D7EDC1','#B9CFE1','#005581']),
'laravel-logo-colors': hex2rgb(['#F05340','#6C6C6C']),
'lastfm-logo-red-colors': hex2rgb(['#D51007']),
'lastpass-colors': hex2rgb(['#D32D27','#AF0809','#000000','#0C2340','#00A3E0','#EDE04B','#333F48','#D9E1E2']),
'ledger-colors': hex2rgb(['#142533']),
'lego-color-codes': hex2rgb(['#E3000B','#FFED00','#000000','#FFFFFF']),
'leicester-city-f-c-logo-colors': hex2rgb(['#0053A0','#FFFFFF','#FDBE11']),
'leidos-holdings-logo-colors': hex2rgb(['#1F1646','#850F88','#BDBEBC']),
'leifheit-logo-colors': hex2rgb(['#D91919']),
'lennar-logo-blue-colors': hex2rgb(['#005DAA']),
'lenovo-color-codes': hex2rgb(['#E42022','#FFFFFF']),
'lenskart-colors': hex2rgb(['#64AF44','#72C7C0','#053A66','#D4E010']),
'lestoil-logo-colors': hex2rgb(['#E4B625','#EFCC4C','#F71924','#DB1829']),
'level-3-communications-logo-colors': hex2rgb(['#211E1E','#EB172B']),
'levis-color-codes': hex2rgb(['#A8112E','#FFFFFF']),
'lg-color-codes': hex2rgb(['#990033','#999999','#FFFFFF']),
'lg-colors': hex2rgb(['#A50034','#6B6B6B']),
'li-fung-logo-colors': hex2rgb(['#E90712','#000000']),
'libertarian-party-united-states-lo-colors': hex2rgb(['#FED105','#56565B']),
'liberty-interactive-logo-colors': hex2rgb(['#F9A537','#000000','#008A5A']),
'libyan-cement-company-lcc-logo-colors': hex2rgb(['#D71921','#231F20']),
'lifepoint-health-logo-colors': hex2rgb(['#1F3D7C','#56585A']),
'limca-logo-colors': hex2rgb(['#01673E','#FFFFFF','#F01516']),
'lincoln-national-logo-colors': hex2rgb(['#98012E','#231F20']),
'lindt-logo-gold-colors': hex2rgb(['#D7B14A']),
'line-colors': hex2rgb(['#06C755','#FFFFFF']),
'line-logo-green-colors': hex2rgb(['#00B900']),
'linkedin-color-codes': hex2rgb(['#0A66C2','#FFFFFF']),
'liquid-plumr-logo-colors': hex2rgb(['#231F20','#ED1C24','#D11C24']),
'lisk-colors': hex2rgb(['#0C152E']),
'litecoin-colors': hex2rgb(['#345D9D','#FFFFFF','#A6A9AA','#4D4D4E']),
'lithia-motors-logo-colors': hex2rgb(['#3D92D5','#000200','#B4B4B6']),
'little-caesars-color-codes': hex2rgb(['#E66200','#000000','#FFFFFF']),
'live-nation-entertainment-logo-red-colors': hex2rgb(['#E61C39']),
'liverpool-f-c-logo-colors-2-2': hex2rgb(['#00A398','#FFFFFF','#D00027','#FDF667']),
'livestream-colors': hex2rgb(['#CF202E','#F78822','#F6DB35','#6DC067','#4185BE','#8F499C']),
'lkq-logo-colors': hex2rgb(['#005596']),
'lockheed-martin-blue-colors': hex2rgb(['#005BAD']),
'loews-logo-blue-colors': hex2rgb(['#0152A1']),
'logistics-management-institute-lmi-colors': hex2rgb(['#232C68','#E65525']),
'loma-negra-logo-colors': hex2rgb(['#E20613','#808080','#1D1D1B']),
'london-spitfire-owl-logo-colors': hex2rgb(['#59CBE8','#FF8200','#1C2B39']),
'london-underground-logo-colors': hex2rgb(['#DE2110','#FFFFFF','#0009AB']),
'long-john-silvers-colors': hex2rgb(['#0C3F87','#A0D5C9','#00A393','#FFFFFF','#EFB59B','#DA1D18']),
'looney-tunes-color-codes': hex2rgb(['#E1393E','#F9A13A','#FFD51F','#000000']),
'looney-tunes-logo-colors': hex2rgb(['#FFD236','#F02F34','#000004']),
'loop-13-colors': hex2rgb(['#00B8FF']),
'los-angeles-angels-mlb-logo-colors': hex2rgb(['#003263','#FFFFFF','#C4CDD3','#CD1141','#8F0028']),
'los-angeles-chargers-team-colors': hex2rgb(['#001433','#F0AE00','#007FC8']),
'los-angeles-dodgers-mlb-logo-colors': hex2rgb(['#EF3E42','#005A9C']),
'los-angeles-gladiators-owl-logo-colors': hex2rgb(['#3C1053','#FFFFFF','#000000']),
'los-angeles-kings-logo-colors': hex2rgb(['#000000','#AEAFAB','#FFFFFF']),
'los-angeles-rams-team-colors': hex2rgb(['#002145']),
'los-angeles-valiant-owl-logo-colors': hex2rgb(['#FBD100','#3289C9']),
'lotte-hotels-resorts-logo-colors': hex2rgb(['#47292B']),
'louis-philippe-logo-colors': hex2rgb(['#040E4E','#A40019']),
'louis-vuitton-colors': hex2rgb(['#000000']),
'lowes-blue-colors': hex2rgb(['#004792']),
'lowes-colors': hex2rgb(['#004990','#FFFFFF']),
'lpga-tour-logo-colors': hex2rgb(['#00518A','#FFFFFF','#F13314','#FFC500','#50BB41']),
'lubuntu-linux-logo-colors': hex2rgb(['#003A72','#0069C9']),
'lufthansa-airlines-logo-colors': hex2rgb(['#0A1D3D']),
'luna-colors': hex2rgb(['#9146FF','#280F32']),
'luno-colors': hex2rgb(['#12326B']),
'lyft-colors': hex2rgb(['#EA0B8C']),
'lysol-logo-colors': hex2rgb(['#005DAA','#BCE6FB','#9F8958','#ED1C24']),
'macys-red-logo-colors': hex2rgb(['#EA0000']),
'madras-rubber-factory-limited-mrf-colors': hex2rgb(['#EF4023']),
'maersk-colors': hex2rgb(['#42B0D5','#000000','#FFFFFF']),
'maggi-noodles-red-and-yellow-colors': hex2rgb(['#ED232A','#FFED00']),
'maggiemoos-ice-cream-and-trea-colors': hex2rgb(['#F00180','#F89BCE','#FFFFFF','#000000','#58BFBA']),
'mahanagar-telephone-nigam-limited-m-colors': hex2rgb(['#037F04']),
'mailchimp-icon-colors': hex2rgb(['#0688BF','#46B8E3','#FFD14F','#684C46','#EABE8D','#F5DCBA']),
'major-league-baseball-logo-colors': hex2rgb(['#000089','#FFFFFF','#CD0001']),
'malabar-cements-limited-logo-colors': hex2rgb(['#C92023','#23278B']),
'manchester-city-f-c-logo-colors': hex2rgb(['#00285E','#6CADDF','#FFFFFF','#FFC758','#D4A11E','#EE3124']),
'manchester-united-f-c-logo-colors': hex2rgb(['#DA020E','#FFE500','#000000']),
'mandarin-oriental-hotel-group-logo-colors': hex2rgb(['#C39122']),
'manly-warringah-sea-eagles-logo-colors': hex2rgb(['#6F0F3B','#ACB1B7','#E4E5E8','#FFFFFF','#182E48']),
'mapbox-colors': hex2rgb(['#4264FB','#FFFFFF']),
'mapei-logo-colors': hex2rgb(['#0077C5']),
'marathon-logo-colors': hex2rgb(['#005DAA','#ED174F']),
'marathon-petroleum-logo-colors': hex2rgb(['#005BAD','#F00D4B']),
'marble-slab-creamery-logo-colors': hex2rgb(['#FFE075','#FFFFFF','#F5ACCC']),
'marlboro-logo-colors': hex2rgb(['#C80000','#B39330']),
'marlboro-red-colors': hex2rgb(['#C80000']),
'marriott-international-logo-colors': hex2rgb(['#B41F3A']),
'marsh-mclennan-logo-colors': hex2rgb(['#002C77','#00A8C7','#016D9E','#A7E2F0']),
'marshalls-blue-logo-colors': hex2rgb(['#182C54']),
'maruti-suzuki-logo-colors': hex2rgb(['#DA241C','#01458E','#1F1A17']),
'marvel-comics-logo-red-colors': hex2rgb(['#ED1D24']),
'marvel-logo-colors': hex2rgb(['#F0131E','#FFFFFF']),
'mary-browns-logo-colors': hex2rgb(['#EF4135','#FDB913','#FFFFFF','#0076C0']),
'masco-website-colors': hex2rgb(['#DBEFF9','#0098E6','#FFE50F','#60B41C','#003987','#F26522']),
'mashable-colors': hex2rgb(['#00AEEF']),
'massachusetts-general-hospital-logo-colors': hex2rgb(['#008BB0']),
'massy-group-logo-colors': hex2rgb(['#004A77','#00ADEE','#FF8100','#FFD200']),
'mastercard-colors': hex2rgb(['#EB001B','#FF5F00','#F79E1B']),
'maurices-logo-colors': hex2rgb(['#48B7B2']),
'maximaa-systems-ltd-logo-colors': hex2rgb(['#0292DA','#2A166E','#DA251C','#EE9E12','#06923E']),
'mccain-foods-logo-colors': hex2rgb(['#FCE502','#FFFFFF','#000000']),
'mckesson-logo-colors': hex2rgb(['#174EA0','#F29130']),
'medion-logo-colors': hex2rgb(['#002B60','#A9A9A9']),
'medion-logo-colors-2': hex2rgb(['#002B60','#A9A9A9']),
'meetup-logo-colors': hex2rgb(['#ED1C40']),
'meijer-logo-colors': hex2rgb(['#0A4D8C','#DD1321']),
'melbourne-football-club-logo-colors': hex2rgb(['#07092D','#CD1A2E']),
'memphis-grizzlies-logo-colors': hex2rgb(['#B9D1EA','#618ABB','#00235E','#FDBA21']),
'meta-color-codes': hex2rgb(['#0668E1','#0080FB','#1C2B33']),
'metlife-logo-colors': hex2rgb(['#008EDD','#0060A2','#A3D043']),
'mgm-resorts-international-logo-colors': hex2rgb(['#B1801E','#D29F53']),
'mi-colors': hex2rgb(['#FF6900','#FFFFFF']),
'miami-dolphins-logo-colors': hex2rgb(['#008E98','#005679','#FFFFFF','#F78200']),
'miami-heat-logo-colors': hex2rgb(['#9A002A','#F9A214','#FFFFFF','#000000']),
'miami-marlins-mlb-logo-colors': hex2rgb(['#FF6600','#FFD100','#FFFFFF','#A7A9AC','#0078C8']),
'miami-vice-logo-colors': hex2rgb(['#0BD2D3','#F990E8','#000000','#FFFFFF']),
'micro-star-international-msi-logo-colors': hex2rgb(['#EB1D24','#A4181D','#D4D3D2','#000000']),
'micron-technology-logo-colors': hex2rgb(['#0077C8']),
'microsoft-edge-blue-colors': hex2rgb(['#0078D7']),
'microsoft-office-365-logo-colors': hex2rgb(['#F25022','#00A4EF','#7FBA00','#FFB900','#737373']),
'microsoft-office-color-codes': hex2rgb(['#B1191B','#EC283F','#B95696','#5C0501','#D83B01','#F18C00']),
'microsoft-teams-logo-colors': hex2rgb(['#464EB8','#7B83EB','#505AC9']),
'microsoft-website-colors': hex2rgb(['#005DA6','#FFFFFF','#616161','#595959','#000000']),
'microsofts-windows-95-logo-colors': hex2rgb(['#000000','#02A5FF','#FF3300','#66CC33','#FFCC00']),
'millennium-copthorne-hotels-logo-colors': hex2rgb(['#C30E2D','#1B1B19']),
'miller-brewing-company-logo-colors': hex2rgb(['#AF1D30','#FFFFFF']),
'minnesota-vikings-team-colors': hex2rgb(['#FFC704','#4F2185','#FFFFFF','#EABF99']),
'minor-hotels-logo-blue-colors': hex2rgb(['#2050A4']),
'minute-maid-logo-colors': hex2rgb(['#231F20','#FFFFFF','#BFD741','#9EBB37','#73962A','#527A23']),
'minute-maid-logo-colors-2': hex2rgb(['#231F20','#FFFFFF','#BFD741','#9EBB37','#73962A','#527A23']),
'mitsubishi-logo-red-colors': hex2rgb(['#E60012']),
'mizuho-financial-group-logo-colors': hex2rgb(['#183181','#ED1A3A']),
'mm-food-market-logo-colors': hex2rgb(['#E55526','#FFFFFF','#26337A']),
'mobikwik-logo-colors': hex2rgb(['#0073CF']),
'mobile-premier-league-mpl-logo-colors': hex2rgb(['#282425','#E1E2E3','#FFFFFF','#C10304','#F60000']),
'mohawk-industries-logo-colors': hex2rgb(['#E51937','#000000']),
'mollie-logo-colors': hex2rgb(['#0092FF','#000000']),
'mondelez-international-logo-colors': hex2rgb(['#502172','#D01414']),
'monopoly-logo-colors': hex2rgb(['#C70000','#BFDBAE','#8FBC72','#FFFFFF','#D7BAAA']),
'monopoly-money-colors': hex2rgb(['#AC96B7','#CA9CA9','#94AC96','#7ABACA','#AE977C','#CAAD50']),
'monsanto-logo-colors': hex2rgb(['#005837','#CA6C18']),
'monster-worldwide-inc-logo-colors': hex2rgb(['#6E46AE','#00B6B4']),
'montreal-expos-colors': hex2rgb(['#00539B','#FFFFFF','#EF3E42']),
'moodys-blue-logo-colors': hex2rgb(['#0028A1']),
'moon-knight-color-codes': hex2rgb(['#000000','#FFFFFF','#A7A7A7','#787878','#ED2924']),
'mopar-logo-colors': hex2rgb(['#0066CC','#000000']),
'mosaic-logo-colors': hex2rgb(['#000000','#00544D','#A88F0A','#9EAB05','#A33D05']),
'motel-6-logo-colors': hex2rgb(['#1476C6','#EE2722']),
'mount-sinai-hospital-manhattan-log-colors': hex2rgb(['#06ABEB','#DC298D','#212070','#00002D']),
'moz-logo-colors': hex2rgb(['#24ABE2']),
'mozilla-firefox-logo-2004-2005-colors': hex2rgb(['#C1330B','#E85D0C','#FCDC25','#002552','#1099D3']),
'mozilla-firefox-logo-2009-2013-colors': hex2rgb(['#D6530F','#900C03','#F8C627','#3778C0','#D3F8FD']),
'mozilla-logo-colors': hex2rgb(['#000000','#FFFFFF']),
'mozilla-old-logo-dinosaur-icon-colors': hex2rgb(['#000000','#FF1B01']),
'mr-clean-logo-colors': hex2rgb(['#F5A4A0','#E83229']),
'mr-muscle-logo-colors': hex2rgb(['#F05523','#FFFFFF','#212B68']),
'mr-sheen-logo-colors': hex2rgb(['#E71B24']),
'mr-sub-red-logo-colors': hex2rgb(['#C31C2C']),
'mrs-logistica-logo-colors': hex2rgb(['#00355B','#FFCF00','#FFED00']),
'ms-dos-logo-colors': hex2rgb(['#000000','#C0C0C0','#FF0000','#FF00FF','#0000FF','#FFFF00']),
'msi-colors': hex2rgb(['#E52629','#A7A9AB','#FFFFFF','#000000']),
'munich-re-logo-colors': hex2rgb(['#165788']),
'murphy-usa-logo-colors': hex2rgb(['#F1F1F1','#235BA8','#DF2027']),
'murphy-warehouse-company-logo-colors': hex2rgb(['#077C47']),
'muut-logo-colors': hex2rgb(['#1EADC5']),
'mysql-colors': hex2rgb(['#00758F','#F29111']),
'nainital-bank-logo-colors': hex2rgb(['#A93C40']),
'namecheap-logo-colors': hex2rgb(['#FE5803','#FF8C44','#6E6F71']),
'nandos-logo-colors': hex2rgb(['#D1011B','#FFFFFF','#000000']),
'nano-colors': hex2rgb(['#4A90E2','#000034','#676686','#F4FAFF']),
'narulas-red-logo-colors': hex2rgb(['#E82200']),
'nasa-colors': hex2rgb(['#0B3D91','#FC3D21','#FFFFFF']),
'national-aluminium-company-nalco-l-colors': hex2rgb(['#1E1917','#AE2828']),
'national-bulk-handling-corporation-colors': hex2rgb(['#00507E','#ED1C24','#F7941E']),
'national-car-rental-logo-colors': hex2rgb(['#8CD50D','#008542']),
'national-environment-agency-nea-lo-colors': hex2rgb(['#BED73B','#74B84B','#AEDFE4','#58B6DC','#6D6E70','#F58A06']),
'national-football-league-nfl-logo-colors': hex2rgb(['#013369','#D50A0A']),
'national-gendarmerie-logo-colors': hex2rgb(['#004790','#D40002']),
'national-geographic-colors': hex2rgb(['#FFD51C','#000000']),
'national-mineral-development-corpora-colors': hex2rgb(['#120083']),
'national-oilwell-varco-logo-colors': hex2rgb(['#B6B5B5','#E51636']),
'national-rugby-league-logo-colors': hex2rgb(['#002E23','#007239','#FFFFFF','#ECBE0C','#FFD700','#FFE700']),
'national-stock-exchange-of-india-lim-colors': hex2rgb(['#E91F2B','#F1B70E','#E07122','#3A2D7F']),
'national-wildlife-federation-nwf-l-colors': hex2rgb(['#6B9F7B','#BFDBF3','#010101']),
'natural-light-color-codes': hex2rgb(['#0D4C92','#00A7E8','#D2202F']),
'natural-resources-defense-council-n-colors': hex2rgb(['#00B3E2','#11274A']),
'navistar-international-logo-colors': hex2rgb(['#006680']),
'nbc-logo-colors': hex2rgb(['#FCB711','#F37021','#CC004C','#6460AA','#0089D0','#0DB14B']),
'ncr-logo-green-colors': hex2rgb(['#54B948']),
'nea-salamis-famagusta-fc-logo-colors': hex2rgb(['#E02520','#FFFFFF']),
'neo-colors': hex2rgb(['#00E599','#00AF92']),
'nest-blue-logo-colors': hex2rgb(['#00C3E8']),
'nestle-colors': hex2rgb(['#000000']),
'netbeans-logo-colors': hex2rgb(['#A1C535','#ADD439','#1B6AC6','#2E90E8','#EA205E','#A5073E']),
'netflix-color-codes': hex2rgb(['#D81F26']),
'new-balance-logo-red-colors': hex2rgb(['#E21836']),
'new-england-patriots-team-colors': hex2rgb(['#C8032B','#002145','#FFFFFF','#B0B7BC']),
'new-orleans-saints-team-colors': hex2rgb(['#D3BC8D', '#000000', '#FFFFFF']),
'new-york-community-bank-logo-colors': hex2rgb(['#000000','#FDAF0A']),
'new-york-excelsior-owl-logo-colors': hex2rgb(['#171C38','#0F57EA','#FF1C26']),
'new-york-giants-team-colors': hex2rgb(['#092067','#A9162D']),
'new-york-jets-team-colors': hex2rgb(['#1F3731','#FFFFFF']),
'newell-brands-logo-colors': hex2rgb(['#298DC1','#696057']),
'newmont-mining-logo-colors': hex2rgb(['#013A81','#A8996E']),
'nexo-colors': hex2rgb(['#60BEFF','#3CA9E5','#2853C3','#1A4199','#2853C3']),
'nextera-energy-logo-colors': hex2rgb(['#78C239','#000000','#0097DA']),
'nick-jr-logo-colors': hex2rgb(['#F69338','#00BEF2']),
'nike-color-codes': hex2rgb(['#000000','#FFFFFF']),
'nike-football-colors': hex2rgb(['#504847','#27A770']),
'nikefuel-colors': hex2rgb(['#4BAD31','#F5DC00','#E95814','#E2142D']),
'nikon-color-codes': hex2rgb(['#FFE100','#FFFFFF','#000000']),
'nintendo-color-codes': hex2rgb(['#E60012','#FFFFFF']),
'nintendo-switch-logo-colors': hex2rgb(['#E70009','#FFFFFF']),
'nissin-logo-colors': hex2rgb(['#E81919','#6F412C']),
'nivea-colors': hex2rgb(['#0032A0','#FFFFFF']),
'nizams-institute-of-medical-s-colors': hex2rgb(['#030301','#FED754','#F20001']),
'nk-celik-zenica-logo-colors': hex2rgb(['#FFEC01','#2A2927','#E31E25']),
'nk-gosk-gabela-logo-colors': hex2rgb(['#0C76BB','#FEFFFC','#ED0D10']),
'nk-inter-zapresic-logo-colors': hex2rgb(['#334889','#FFF00F','#FFFFFD']),
'nk-istra-1961-logo-colors': hex2rgb(['#0B0C06','#F6EA2C','#43B74C','#1B7A74','#8D7E74']),
'nk-lokomotiva-logo-colors': hex2rgb(['#926A27','#CCA24E','#2C5392','#2C2C2C','#ACADAD']),
'nk-osijek-logo-colors': hex2rgb(['#231F20','#1061AF','#FFFFFF','#38B4E7']),
'nk-rudes-logo-colors': hex2rgb(['#EE2523','#FFFFFF','#2760B5']),
'nk-siroki-brijeg-logo-colors': hex2rgb(['#ED202B','#FFFFFF','#000000','#1D4B8F','#FACD4B']),
'nk-slaven-belupo-logo-colors': hex2rgb(['#C7A36F','#DC4738','#FFFFFF','#62B4E2','#D7C80E','#005197']),
'nk-vitez-logo-colors': hex2rgb(['#FDF21C','#0097F0','#CB010B','#FDFDFD','#EAE7E0']),
'nokia-logo-colors': hex2rgb(['#124191']),
'nominex-colors': hex2rgb(['#00A0FF']),
'norcem-logo-colors': hex2rgb(['#231F20','#15569C']),
'north-queensland-cowboys-logo-colors': hex2rgb(['#002B5C','#FFFFFF','#FFDD02']),
'north-texas-mean-green-logo-colors': hex2rgb(['#00853E','#000000']),
'northern-trust-logo-colors': hex2rgb(['#115740']),
'northrop-grumman-blue-logo-colors': hex2rgb(['#0069B0']),
'northwestern-mutual-logo-colors': hex2rgb(['#FFB800','#032A4A']),
'norton-antivirus-symantec-corporati-colors': hex2rgb(['#FDB511','#000000','#9A9A9A']),
'nottingham-forest-f-c-logo-colors': hex2rgb(['#E53233']),
'novartis-colors': hex2rgb(['#E8580F','#006A9E','#F7B516']),
'novotel-logo-colors': hex2rgb(['#171E52']),
'novotel-old-logo-colors': hex2rgb(['#01335D','#FFFFFF','#EF9B0C']),
'npr-national-public-radio-logo-colors': hex2rgb(['#F15B1C','#00000F','#FFFFFF','#4C85C5']),
'ns1-logo-colors-2': hex2rgb(['#211F1F','#EE1A6E']),
'nuclear-power-corporation-of-india-colors': hex2rgb(['#000099']),
'nuvera-communications-color-codes': hex2rgb(['#DA1A32','#15BEF0','#D3DF4E','#000000']),
'nvidia-colors': hex2rgb(['#76B900','#000000']),
'nxp-colors': hex2rgb(['#F9B500','#7BB1DB','#C9D200','#958437','#739833']),
'nyati-cement-logo-colors': hex2rgb(['#F99655','#2A3C64']),
'nzxt-colors': hex2rgb(['#51007A','#DBE800','#D0D3D4','#7C878E']),
'oakland-raiders-team-colors': hex2rgb(['#A5ACAF','#000000']),
'occidental-petroleum-logo-colors': hex2rgb(['#005BAC','#ED1C2E']),
'oceania-football-confederation-ofc-colors': hex2rgb(['#1A3374','#40B93C','#D9E70C']),
'oculus-website-colors': hex2rgb(['#1D1F20','#0073D0','#0089FA']),
'office-depot-logo-red-colors': hex2rgb(['#CC0000']),
'ola-cabs-logo-colors': hex2rgb(['#D7DF23','#000000']),
'ola-green-colors': hex2rgb(['#D6DF22']),
'ola-logo-colors': hex2rgb(['#000000','#D6DF22']),
'olark-colors': hex2rgb(['#744DA8','#1FB3E0','#49C219','#F4DC2A','#EEB417','#D65129']),
'old-android-green-colors': hex2rgb(['#A4C639']),
'old-navy-color-codes': hex2rgb(['#003764','#FFFFFF']),
'old-republic-international-logo-blue-colors': hex2rgb(['#1F3D7D']),
'oldcastle-materials-inc-logo-colors': hex2rgb(['#00573B']),
'olive-garden-logo-colors': hex2rgb(['#54301A','#E4E1DC','#A8AD00']),
'olive-garden-website-colors': hex2rgb(['#DED8CC','#E3E1DB','#FFFFFF','#9A3325','#CBCE65','#A8AD00']),
'olx-colors': hex2rgb(['#5C307F','#BEC100','#FF8100']),
'olympic-logos-and-symbols-colors': hex2rgb(['#0085C7','#F4C300','#000000','#009F3D','#DF0024']),
'oman-air-airlines-logo-colors': hex2rgb(['#A7A9AC','#B5985A']),
'onenote-color-codes': hex2rgb(['#7218A5','#9332BF','#AE4BD5','#CA64EA','#FFFFFF']),
'onenote-purple-colors': hex2rgb(['#7719AA']),
'onenote-purple-colors-2': hex2rgb(['#7719AA']),
'oneok-logo-colors': hex2rgb(['#0093D0','#717174']),
'onshape-logo-colors': hex2rgb(['#0A3AA1']),
'ontology-colors': hex2rgb(['#48A3FF','#000000']),
'openbsd-logo-colors': hex2rgb(['#1E1812','#F2CA30','#FEF67A','#CF4229']),
'opera-logo-colors': hex2rgb(['#FF1B2D','#CB0B1E','#B20317','#FE4A4A']),
'oracle-colors': hex2rgb(['#C74634']),
'oral-b-logo-colors': hex2rgb(['#1574C4','#FFFFFF']),
'orange-colors': hex2rgb(['#FF6600','#FFFFFF']),
'orchid-colors': hex2rgb(['#5F45BA']),
'oreilly-automotive-logo-colors': hex2rgb(['#009D57','#FFFFFF','#000000','#CD2029']),
'orient-overseas-international-limi-colors': hex2rgb(['#FF0000']),
'orient-overseas-international-limi-colors-2': hex2rgb(['#FF0000']),
'oriental-bank-of-commerce-logo-colors': hex2rgb(['#4CB848']),
'origene-logo-colors': hex2rgb(['#60A243','#00733B']),
'original-aetna-logo-colors': hex2rgb(['#FFE75A','#004791','#007FC8']),
'oshkosh-logo-colors': hex2rgb(['#000000','#EA7600']),
'outlook-com-logo-blue-colors-2': hex2rgb(['#0072C6']),
'ovation-brands-logo-colors': hex2rgb(['#536794','#9D9FA2']),
'owens-illinois-logo-colors': hex2rgb(['#E86F2A','#2370B8']),
'owens-minor-logo-colors': hex2rgb(['#98012E','#939598']),
'oxford-english-dictionary-oed-colors': hex2rgb(['#B2231F','#01356F','#66AD4D']),
'oxford-university-press-logo-colors': hex2rgb(['#1D2C4F']),
'pacific-basin-shipping-limited-logo-colors': hex2rgb(['#005DAA','#162731']),
'pacific-life-logo-colors': hex2rgb(['#018ED7','#004685','#8C8C8C']),
'padang-cement-logo-colors': hex2rgb(['#D73438','#363435']),
'pafos-fc-logo-colors': hex2rgb(['#161747','#297CA6','#9ACCE3','#FDDC01','#E5E8ED','#6D89AE']),
'pakistan-national-cricket-team-logo-colors': hex2rgb(['#006629','#B59A0A']),
'pakistan-super-league-psl-logo-colors': hex2rgb(['#00A997','#414143','#D7DF27','#026838']),
'pallavi-model-school-pms-logo-colors': hex2rgb(['#D1A447','#F7E9A4','#A80B03','#107D29','#0064B1']),
'palmolive-logo-colors': hex2rgb(['#075D59','#9C912E','#737E3B','#CCD79F']),
'pan-american-world-airways-logo-colors': hex2rgb(['#2767AD','#FFFFFF']),
'panasonic-colors': hex2rgb(['#0041C0']),
'pancakeswap-colors': hex2rgb(['#633001','#D1884F','#FEDC90']),
'pantaloons-logo-green-colors': hex2rgb(['#00AA8A']),
'pantos-logistics-logo-colors': hex2rgb(['#C40035','#727272']),
'paradise-biryani-food-court-logo-colors': hex2rgb(['#88191C','#F9F7C2','#F9692A']),
'paris-eternal-owl-logo-colors': hex2rgb(['#303D56','#8D042D','#FFAA1D']),
'park-plaza-hotels-resorts-logo-colors': hex2rgb(['#004A85','#1E1917']),
'parle-agro-logo-colors': hex2rgb(['#ED1B24','#00A54F']),
'parle-products-logo-red-colors': hex2rgb(['#FF0000']),
'parramatta-eels-logo-colors': hex2rgb(['#006EB5','#FFFFFF','#FFD326','#90C84B']),
'patanjali-ayurved-logo-colors': hex2rgb(['#942C2B','#7BB82F','#E56E1E']),
'paxful-colors': hex2rgb(['#000000','#00A5EF']),
'paxos-colors': hex2rgb(['#005121','#51B849','#00845D','#B3D234','#EEE809','#0095D9','#778F9B']),
'paytm-logo-colors': hex2rgb(['#002E6E','#00B9F1']),
'paytm-mall-red-colors': hex2rgb(['#EF4E28']),
'pbf-energy-logo-colors': hex2rgb(['#C51230','#0053A3']),
'pedigree-petfoods-logo-colors': hex2rgb(['#F6B40D','#FFFFFF','#1E4775']),
'penske-logo-colors': hex2rgb(['#ED1B2E','#F8F7F8','#ABACAE','#000000']),
'peoples-united-financial-logo-colors': hex2rgb(['#002D72','#9D2235']),
'perfetti-van-melle-logo-colors': hex2rgb(['#004792','#F12E15']),
'performance-food-logo-colors': hex2rgb(['#EA1B25']),
'pernod-ricard-logo-colors': hex2rgb(['#79ACD2','#002957']),
'petco-color-codes': hex2rgb(['#001952','#EA2229','#009DDC','#000000']),
'peter-piper-pizza-logo-2000-2013-colors': hex2rgb(['#5E0088','#E8C81B','#F2E213','#D1052A']),
'peter-piper-pizza-logo-colors': hex2rgb(['#FF2A1E','#FFB700','#D3E11D','#46C230']),
'pfizer-logo-colors': hex2rgb(['#0070BF','#00AFF0']),
'pga-of-america-logo-colors': hex2rgb(['#0D2363','#FFFFFF','#CCA600']),
'pga-tour-logo-colors': hex2rgb(['#003C80','#FFFFFF','#F1373D']),
'philadelphia-eagles-team-colors': hex2rgb(['#004C55','#A5ACAF','#FFFFFF','#000000']),
'philadelphia-fusion-owl-logo-colors': hex2rgb(['#FF9E1B','#FFFFFF','#000000']),
'philip-morris-international-colors': hex2rgb(['#4EA2DA']),
'phillips-66-logo-colors': hex2rgb(['#CF2421','#FFFFFF','#000000']),
'phoenix-firebird-2002-2004-colors': hex2rgb(['#FFCC00','#CB2127','#EE2224','#F26722']),
'photobucket-logo-colors': hex2rgb(['#FFFFFF','#000000']),
'php-logo-colors': hex2rgb(['#AEB2D5','#777BB3','#484C89','#000000','#FFFFFF']),
'phpmyadmin-logo-colors': hex2rgb(['#6C78AF','#F89C0E','#CCCCCC']),
'picasa-logo-colors': hex2rgb(['#E9EAEB','#9B479F','#E04A3F','#FFD34E','#0DAB62','#448AFD']),
'picasa-logo-colors-2': hex2rgb(['#E9EAEB','#9B479F','#E04A3F','#FFD34E','#0DAB62','#448AFD']),
'pine-sol-logo-colors': hex2rgb(['#1E160D','#BFA800','#FFE101']),
'pita-pit-logo-colors': hex2rgb(['#D1432F','#F2B279','#F7FCFE','#9CC43C','#00A14E','#016B38']),
'pittsburgh-steelers-team-colors': hex2rgb(['#000000','#A5ACAF','#00519D','#C8032B','#F0AE00']),
'pkl-bengal-warriors-ben-logo-colors': hex2rgb(['#00284E','#FFFFFF','#F26724','#F0D41C']),
'pkl-bengaluru-bulls-bgb-logo-colors': hex2rgb(['#000000','#B40C19','#FFFFFF','#FFCA02']),
'pkl-dabang-delhi-dbd-logo-colors': hex2rgb(['#D6222D','#C88B2D','#F2F24F']),
'pkl-gujarat-fortune-giants-colors': hex2rgb(['#402113','#FFAB3B','#F41E2D','#FB9241','#FFB171','#000000']),
'pkl-haryana-steelers-har-logo-colors': hex2rgb(['#888787','#E2E3E4','#252D76','#C3202D','#ED1D25']),
'pkl-jaipur-pink-panthers-jp-colors': hex2rgb(['#ED408F','#D12D84','#71C1F6','#FFFFFF','#000000']),
'pkl-puneri-paltan-pnp-logo-colors': hex2rgb(['#FFCC00','#FF4300','#990000','#000000','#807F7F','#EDEDEE']),
'pkl-tamil-thalaivas-logo-colors': hex2rgb(['#1E2A67','#D4A93C','#FAC42F']),
'pkl-telugu-titans-logo-colors': hex2rgb(['#000002','#D9202C','#CAA336','#EAC039']),
'pkl-u-mumba-logo-colors': hex2rgb(['#F05922','#231F20','#F3B23E','#A37D2C']),
'pkl-up-yoddha-logo-colors': hex2rgb(['#01246C','#E20619','#FFD249']),
'plains-all-american-pipeline-logo-colors': hex2rgb(['#00295D','#A1A3A6','#D50642']),
'planet-fashion-logo-colors': hex2rgb(['#ED1C24','#231F20']),
'planet-fitness-color-codes': hex2rgb(['#000000','#F9F72E','#A4278D','#FFFFFF']),
'plasso-colors': hex2rgb(['#F5756C','#2F3148','#6585ED','#98AFC0']),
'playstation-blue-colors': hex2rgb(['#006FCD']),
'pledge-logo-colors': hex2rgb(['#F0CB45','#FFDE26','#043553','#7184A6','#1EAFEF']),
'pluralsight-logo-colors': hex2rgb(['#F15B2A','#EC008C','#FFFFFF','#000000']),
'pocket-logo-colors': hex2rgb(['#83ECB8','#50BBB6','#ED4255','#FBB64A']),
'pointpay-colors': hex2rgb(['#101541','#4F80F4','#0EE6E7']),
'police-nationale-france-logo-colors': hex2rgb(['#1C4992','#FFFFFF','#E02621','#000000']),
'polkadot-colors': hex2rgb(['#E6007A','#000000']),
'pool-surgeon-colors': hex2rgb(['#00A3E4','#4DC8E9','#0072AE']),
'popular-inc-logo-colors': hex2rgb(['#EE3A3F','#211E1E']),
'postman-colors': hex2rgb(['#EF5B25']),
'powerpoint-color-codes': hex2rgb(['#C13B1B','#D35230','#ED6C47','#FF8F6B','#FFFFFF']),
'powerpuff-girls-logo-colors': hex2rgb(['#F6ADCD','#FFF200','#000000']),
'ppg-industries-logo-colors': hex2rgb(['#0078A9']),
'ppl-logo-colors': hex2rgb(['#1882C5','#28317E']),
'pradhan-mantri-kaushal-vikas-yojana-colors': hex2rgb(['#764C29','#F36F23']),
'praxair-logo-colors': hex2rgb(['#00A865']),
'praxair-logo-colors-2': hex2rgb(['#00A865']),
'prestashop-colors': hex2rgb(['#DF0067','#251B5B','#68737F','#25B9D7','#FBBB22']),
'priceline-group-logo-colors': hex2rgb(['#7893A4']),
'primary-health-care-logo-colors': hex2rgb(['#1E3E72','#D88DBC','#F37336','#F7CC3B','#5ABA4A','#63C8F2']),
'primary-health-care-logo-colors-2': hex2rgb(['#1E3E72','#D88DBC','#F37336','#F7CC3B','#5ABA4A','#63C8F2']),
'prince-hotels-logo-colors': hex2rgb(['#847A4D']),
'principal-financial-logo-colors': hex2rgb(['#0076BC','#00BCD8','#555A5B']),
'pro-kabaddi-league-pkl-logo-colors': hex2rgb(['#EE6C21','#24803D']),
'procter-gamble-blue-colors': hex2rgb(['#0037B1']),
'product-hunt-logo-colors': hex2rgb(['#DA552F']),
'progressive-blue-logo-colors': hex2rgb(['#0053BA']),
'prudential-logo-blue-colors': hex2rgb(['#0078C4']),
'psl-peshawar-zalmi-logo-colors': hex2rgb(['#FFC20F','#073050','#FFFFFF']),
'public-service-enterprise-group-logo-colors': hex2rgb(['#F37022','#231F20']),
'pultegroup-logo-colors': hex2rgb(['#FBF056','#033764','#E4A031']),
'punjab-national-bank-pnb-logo-colors': hex2rgb(['#FBBC09','#A20E37']),
'purex-laundry-detergent-logo-colors': hex2rgb(['#0D165D','#2D70BC','#D1E5F8']),
'putty-logo-icon-colors': hex2rgb(['#000000','#808080','#BFBFBF','#FFFFFF','#FFFF00','#0000FF']),
'python-logo-colors': hex2rgb(['#4B8BBE','#306998','#FFE873','#FFD43B','#646464']),
'qarabag-fk-logo-colors': hex2rgb(['#CF8A15','#312758','#FEFEFE','#F8F6E8']),
'qatar-national-cement-company-logo-colors': hex2rgb(['#A3224C']),
'qdoba-color-codes': hex2rgb(['#F99D1C','#000000']),
'qtum-colors': hex2rgb(['#2CA6E0','#3E3A39']),
'qualcomm-colors': hex2rgb(['#3253DC']),
'quanta-services-logo-colors': hex2rgb(['#231F20','#FDBF57','#ED1B2D']),
'quest-diagnostics-logo-colors': hex2rgb(['#B9C930','#4A7637']),
'quikr-logo-colors': hex2rgb(['#1FAC4B','#1580C1']),
'quintiles-ims-holdings-logo-colors': hex2rgb(['#1DAAE3','#B0E1F5','#864599','#595959']),
'quiznos-logo-colors': hex2rgb(['#E21F26','#D0AB7B','#4D7335']),
'quora-logo-colors': hex2rgb(['#B92B27']),
'raising-canes-chicken-fingers-logo-colors': hex2rgb(['#D11920','#FFFFFF','#070707','#FFF104','#FDBD14','#A15914']),
'rakuten-colors': hex2rgb(['#BF0000']),
'ral-orange-logo-colors': hex2rgb(['#FE6C35']),
'ramco-cements-logo-colors': hex2rgb(['#0B3F8B','#EA1F22']),
'ramraj-cotton-logo-colors': hex2rgb(['#004D1C','#FFEC00','#FFFCE4','#E40015']),
'ramraj-green-yellow-colors': hex2rgb(['#004D1C','#FFEC00']),
'ranker-logo-colors': hex2rgb(['#C40529','#1D3F66']),
'raymond-james-financial-logo-colors': hex2rgb(['#002949']),
'raytheon-red-logo-colors': hex2rgb(['#E61231']),
'razer-inc-logo-colors': hex2rgb(['#66B933','#000000']),
'razorpay-logo-colors': hex2rgb(['#012652','#0D94FB']),
'rbc-bank-logo-colors': hex2rgb(['#005DAA','#FFD200','#FFFFFF']),
'rc-cola-color-codes': hex2rgb(['#00539A','#ED3224','#F16846','#BFC0C2','#FFFFFF']),
'real-madrid-c-f-logo-colors': hex2rgb(['#00529F','#FEBE10','#FFFFFF','#EE324E']),
'real-sociedad-logo-colors': hex2rgb(['#143C8B','#FFFFFF','#E6A515','#FFE249','#EC2C23']),
'realme-colors': hex2rgb(['#676C73']),
'realme-logo-colors': hex2rgb(['#111111','#FFC916']),
'red-bull-color-codes': hex2rgb(['#FF0C49','#FFC800']),
'red-hat-logo-colors': hex2rgb(['#CC0000','#FFFFFF','#000000']),
'red-lion-hotels-corporation-logo-colors': hex2rgb(['#AA2723']),
'red-lobster-logo-colors': hex2rgb(['#000000','#FFFFFF','#770524','#E40F3A','#F28DA2']),
'reddit-color-codes': hex2rgb(['#FF4500','#000000','#FFFFFF']),
'redis-logo-colors': hex2rgb(['#D82C20','#A41E11','#7A0C00','#FFFFFF','#636466']),
'regions-financial-corporation-logo-colors': hex2rgb(['#84BD00','#658D1B']),
'reliance-industries-limited-colors': hex2rgb(['#BFA161','#000000']),
'reliance-steel-aluminum-logo-colors': hex2rgb(['#40695A','#8A8A8D','#003A5D']),
'republic-services-logo-colors': hex2rgb(['#D81A4A','#00427D']),
'republican-party-logo-gop-u-colors': hex2rgb(['#1404BD','#DE0100']),
'revain-colors': hex2rgb(['#5E2CF2']),
'reynolds-american-logo-colors': hex2rgb(['#0089BB','#E96E31','#FDD60C','#468C42','#C5D435']),
'rinso-logo-colors': hex2rgb(['#00A7E7','#9CC31B','#FEED04','#E30611']),
'rio-2016-colors': hex2rgb(['#2B9935','#57B52F','#F2511C','#FCCC06','#3FA3DA','#4ABFEE']),
'ripple-colors': hex2rgb(['#00AAE4','#006097','#0085C0','#434C54']),
'rite-aid-logo-colors': hex2rgb(['#004D9B','#F23C3C']),
'riu-hotels-logo-colors': hex2rgb(['#D2232A','#CA9C4E']),
'robinhood-colors': hex2rgb(['#000000']),
'robins-donuts-logo-colors': hex2rgb(['#000000','#FDF78E','#AD1F35','#FFEE1F','#FFFFFF','#F1C9C0']),
'rolls-royce-logo-colors': hex2rgb(['#00498F','#FFFFFF']),
'roo-kids-logo-colors': hex2rgb(['#A0CF2D','#FFFFFF','#E51C1C','#450000']),
'rose-gold-color': hex2rgb(['#E6C7C2']),
'ross-stores-logo-colors': hex2rgb(['#468CC6']),
'royal-canin-logo-colors': hex2rgb(['#E42C31']),
'royal-caribbean-international-colors': hex2rgb(['#061556','#0073BB','#FEBD11']),
'royal-stag-colors': hex2rgb(['#66211F','#DEBE71','#BE9F67']),
'ruby-on-rails-logo-red-colors': hex2rgb(['#CC0000']),
'ruby-tuesday-logo-colors': hex2rgb(['#D31145','#231F20','#808284']),
'rumo-s-a-logo-colors': hex2rgb(['#01385F']),
'rvcj-logo-colors': hex2rgb(['#2EC8AE','#E94268','#E824AF','#9542E9']),
'ryans-red-logo-colors': hex2rgb(['#C5161D']),
'ryder-system-logo-colors': hex2rgb(['#CE2028','#000000']),
's-o-s-soap-pad-logo-colors': hex2rgb(['#F36C4E','#EC1B22','#0090D6','#0156A8']),
'sagar-colors': hex2rgb(['#005EA5','#F47738','#04A44C','#E9E9E9','#333333']),
'sagtco-progressive-2019-colors': hex2rgb(['#1E81C3','#ED641E','#ED2828','#FCD33D']),
'salem-cigarettes-colors': hex2rgb(['#248D7E','#C8B84F','#FDF8E0','#144452']),
'salesforce-com-logo-blue-colors': hex2rgb(['#21A0DF']),
'salonit-anhovo-logo-colors': hex2rgb(['#0D80C8']),
'san-francisco-shock-owl-logo-colors': hex2rgb(['#FC4C02','#75787B','#CAB64B']),
'sanmina-logo-colors': hex2rgb(['#EE3A43','#000000']),
'santander-bank-logo-colors': hex2rgb(['#EA1D25']),
'santos-brasil-logo-colors': hex2rgb(['#009038','#006EC7']),
'sarahah-colors': hex2rgb(['#10BAB2']),
'sarpinos-pizzeria-logo-colors': hex2rgb(['#004F39','#C5B9A0','#FFFFFF','#EE2E24']),
'sashastra-seema-bal-ssb-logo-colors': hex2rgb(['#05366D','#B19149']),
'sass-logo-pink-colors': hex2rgb(['#CD6799']),
'save-the-children-logo-colors': hex2rgb(['#ED1B2D','#000000']),
'sbarro-logo-colors': hex2rgb(['#FF0000','#000000','#006800']),
'schemecolor-logo-colors-2': hex2rgb(['#4DC4CB','#FDC75D','#F58B65']),
'scrub-daddy-logo-colors': hex2rgb(['#0054A6','#FFF200','#FFB500']),
'sealed-air-logo-colors': hex2rgb(['#007F84','#ADCA35','#FCC537']),
'sears-blue-logo-colors': hex2rgb(['#002F9C']),
'seattle-seahawks-team-colors': hex2rgb(['#002145','#A5ACAF','#66C010']),
'semapa-logo-colors': hex2rgb(['#00205A']),
'sempra-energy-logo-colors': hex2rgb(['#E01049','#204394']),
'seoul-dynasty-owl-logo-colors': hex2rgb(['#000000','#FFFFFF','#AA8A00']),
'septa-colors': hex2rgb(['#1F4FA3','#F14728']),
'shanghai-dragons-owl-logo-colors': hex2rgb(['#D22630','#000000','#FFFFFF','#FCE300']),
'shanghai-international-port-group-s-colors': hex2rgb(['#133984']),
'shangri-la-hotels-and-resorts-logo-colors': hex2rgb(['#BB9754','#231F20']),
'shazam-logo-colors': hex2rgb(['#00AAFF','#0991FF','#196AFF','#2255FF']),
'shell-logo-colors': hex2rgb(['#DA291C','#FFCD00']),
'shenzhen-international-holdings-logo-colors': hex2rgb(['#6C6E70']),
'sherwin-williams-logo-colors': hex2rgb(['#EF4135','#FFFFFF','#0067B1']),
'shopclues-logo-colors': hex2rgb(['#24A3B5','#181818']),
'siam-cement-group-scg-logo-colors': hex2rgb(['#EC1C24']),
'sify-logo-colors': hex2rgb(['#BDD70C']),
'silicon-valley-bank-logo-colors': hex2rgb(['#00A1E4','#005B7F']),
'skoda-colors': hex2rgb(['#00800D']),
'slideshare-colors': hex2rgb(['#0077B5']),
'smashing-magazine-logo-colors': hex2rgb(['#D33B2C','#FFFFFF']),
'snapdeal-old-logo-colors': hex2rgb(['#189FCC','#C00309']),
'snapfish-by-hp-colors': hex2rgb(['#00A2E3','#6FBF42','#242021']),
'snapple-logo-colors': hex2rgb(['#F1AF00','#0052A7']),
'snapseed-colors': hex2rgb(['#0B552B','#0B8142','#32AC71','#B2FF59','#AED580','#8BC249']),
'socialbro-logo-colors': hex2rgb(['#29C4D0','#F29556','#84AFA2','#72C427','#F24C7C','#00AAF2']),
'sonicbids-logo-colors': hex2rgb(['#F58455','#FFFFFF','#D0DFE7','#0D87B1','#231F20']),
'sony-entertainment-television-logo-colors': hex2rgb(['#080808','#F8F9FA','#4C1A6F','#9231CE','#CDB748','#FEE78A']),
'south-american-football-confederatio-colors': hex2rgb(['#005CA4']),
'south-indian-bank-colors': hex2rgb(['#AA0000']),
'southwest-airlines-logo-colors': hex2rgb(['#2E4BB1','#3453C4','#CCCCCC','#E51D23','#F9B612']),
'spangles-logo-colors': hex2rgb(['#E51A37','#FFFFFF','#FFF100']),
'sparkasse-web-site-colors': hex2rgb(['#FF0002','#FFFFFF','#BBBBBB','#666666']),
'spirit-aerosystems-holdings-logo-colors': hex2rgb(['#1946BA']),
'spongebob-squarepants-logo-colors': hex2rgb(['#AEAD0D','#FFF56C','#26B9C8','#0457A0']),
'sprite-alternate-logo-1961-1974-colors': hex2rgb(['#25881E','#F64108']),
'sprite-logo-1974-1989-colors': hex2rgb(['#016438','#FF2909']),
'sprite-logo-international-1989-1-colors': hex2rgb(['#00984A','#FFF301']),
'sprite-logo-united-states-2010-2-colors': hex2rgb(['#204795','#02A04C','#F7D704','#FFFFFF','#DEDEDF']),
'sprout-social-logo-colors': hex2rgb(['#63DD6F','#3FCB62','#00B65B','#00A756','#354141']),
'st-louis-blues-logo-colors': hex2rgb(['#002053','#002B88','#FFFFFF','#FCB60C']),
'st-louis-cardinals-mlb-logo-colors': hex2rgb(['#B72126','#FEE60E','#14264B']),
'stack-overflow-logo-colors': hex2rgb(['#F47F24','#BCBBBB','#222426']),
'stackedit-logo-colors': hex2rgb(['#BBD500','#FFE600','#75B7FD','#FF8A00','#737373','#555555']),
'staples-logo-colors': hex2rgb(['#CD0001']),
'staples-red-logo-colors': hex2rgb(['#CE0000']),
'star-alliance-logo-colors': hex2rgb(['#000000','#5B5B63','#92959B','#CDD0D3']),
'star-chinese-channel-logo-colors': hex2rgb(['#B5D22C','#73AA2A','#0995AE','#04506A']),
'star-movies-logo-colors': hex2rgb(['#211D70','#FFC20E']),
'star-wars-logo-colors': hex2rgb(['#000000']),
'state-farm-red-colors': hex2rgb(['#F01716']),
'state-street-corporation-logo-colors': hex2rgb(['#0067B1']),
'steel-dynamics-logo-colors': hex2rgb(['#D7283F','#231F20']),
'stef-logo-colors': hex2rgb(['#00A8EC','#2D4C9C']),
'sterling-hotels-logo-colors': hex2rgb(['#FBAD1B','#EF4F38','#8B2782']),
'storck-logo-colors': hex2rgb(['#000000','#FFA800','#FF1300']),
'strava-colors': hex2rgb(['#FC4C02']),
'stumbleupon-logo-colors': hex2rgb(['#EB471D']),
'suavitel-logo-colors': hex2rgb(['#2E3192','#23B4E7','#EC008C']),
'sublime-text-logo-colors': hex2rgb(['#4C4C4C','#FF9800']),
'sumgayit-fk-logo-colors': hex2rgb(['#0469AE','#273E74','#F55935','#018C4C','#FFFFFF']),
'sun-country-airlines-logo-colors': hex2rgb(['#F58232','#004885']),
'sun-life-financial-logo-colors': hex2rgb(['#0E3846','#ECAB23']),
'suntrust-banks-logo-colors': hex2rgb(['#EF7622','#003B71']),
'super-8-motels-logo-colors': hex2rgb(['#FAEF36','#ED3552','#FFFFFF','#292929']),
'super-fresh-logo-colors': hex2rgb(['#436BB3','#FFFFFF','#79C145']),
'super-mario-logo-colors': hex2rgb(['#009BD9','#FCCF00','#E62310','#44AF35','#000000']),
'superman-logo-colors': hex2rgb(['#C80000','#FFEB00','#000000']),
'suzuki-logo-colors': hex2rgb(['#E20A17','#003399']),
'sv-mattersburg-logo-colors': hex2rgb(['#007C2E','#FFFFFF']),
'sv-werder-bremen-logo-colors': hex2rgb(['#1D9053','#FFFFFF']),
'swachh-bharat-abhiyan-colors': hex2rgb(['#EBAA17','#FEFEFE','#2DB548','#161712']),
'swagbucks-logo-colors': hex2rgb(['#54B5D2']),
'swiffer-logo-colors': hex2rgb(['#20409A','#0069B1','#0091C8','#16B585','#AED137','#FCB815']),
'swiggy-logo-colors': hex2rgb(['#FC8019']),
'swiggy-logo-colors-2': hex2rgb(['#FC8019']),
'swiss-international-air-lines-logo-colors': hex2rgb(['#E60005','#FFFFFF']),
'sydney-roosters-logo-colors': hex2rgb(['#00305E','#FFFFFF','#FFD74F','#E82C2E']),
'synchrony-financial-logo-yellow-colors': hex2rgb(['#FFB700']),
'synnex-logo-colors': hex2rgb(['#01505D']),
'synovus-logo-colors': hex2rgb(['#ED1C24']),
'sysco-logo-colors': hex2rgb(['#0088D8','#4BB92C']),
't-mobile-color-codes': hex2rgb(['#E2007A','#999B9E']),
'tabasco-red-hot-sauce-colors': hex2rgb(['#008052','#CB240F','#88180A']),
'taco-bell-color-codes': hex2rgb(['#682A8D','#A07EBA','#000000']),
'taj-hotels-resorts-and-palaces-logo-colors': hex2rgb(['#8E744B']),
'tally-colors': hex2rgb(['#008080','#D6F6D6']),
'tamilnad-mercantile-bank-limited-log-colors': hex2rgb(['#C72E8F','#3052A1']),
'tampa-bay-buccaneers-team-colors': hex2rgb(['#D70100','#B1BABF','#0E0E0E','#FF7900']),
'target-color-codes': hex2rgb(['#CC0000','#FFFFFF']),
'tata-blue-colors': hex2rgb(['#486AAE']),
'tata-docomo-logo-colors': hex2rgb(['#F07D00','#FBB40E','#E31B13','#000000']),
'tcby-logo-colors': hex2rgb(['#EC008C','#B6B7BA']),
'tcby-red-logo-colors': hex2rgb(['#C51230']),
'td-bank-n-a-logo-colors': hex2rgb(['#54B948','#FFFFFF']),
'team-trees-logo-colors': hex2rgb(['#8AB740','#263754']),
'teenage-mutant-ninja-turtles-color-codes': hex2rgb(['#8FD129','#ED1C28','#000000','#FFFFFF']),
'telecom-regulatory-authority-of-indi-colors': hex2rgb(['#00448B']),
'telefonica-web-site-colors': hex2rgb(['#003345','#0F6475','#1B8697','#F4F4F4','#DFDFDF']),
'telegram-color-codes': hex2rgb(['#27A7E7','#FFFFFF']),
'tenet-healthcare-logo-colors': hex2rgb(['#1F6094','#F88E1B']),
'tenneco-logo-colors': hex2rgb(['#946244','#000000']),
'tennessee-titans-team-colors': hex2rgb(['#16233F','#4790DE','#A5ACAF','#FFFFFF','#C8032B']),
'tesla-colors': hex2rgb(['#E82127']),
'tesla-logo-red-colors': hex2rgb(['#E82127']),
'tether-colors': hex2rgb(['#26A17B','#5B5A5D','#FFFFFF']),
'texas-instruments-logo-colors': hex2rgb(['#CC0000','#000000']),
'texas-roadhouse-logo-colors': hex2rgb(['#E13223','#FFDD02','#000000','#FFFFFF','#439539']),
'textron-logo-blue-colors': hex2rgb(['#005290']),
'tezos-colors': hex2rgb(['#2C7DF7']),
'the-ascott-limited-logo-colors': hex2rgb(['#9E7B5D','#011E46']),
'the-boring-company-colors': hex2rgb(['#000000','#FFFFFF']),
'the-childrens-place-logo-colors': hex2rgb(['#00ADEF']),
'the-human-bean-logo-colors': hex2rgb(['#2F1C10']),
'the-next-web-colors': hex2rgb(['#FF3C1F','#26313B','#4E5860','#A6ABAF','#D9E0E2']),
'the-pizza-company-logo-colors': hex2rgb(['#DE1E27','#FFFFFF','#000000','#028F46']),
'the-powerpuff-girls-color-codes': hex2rgb(['#AC016B','#EF72A5','#F7AEC7','#000000']),
'the-sun-logo-colors': hex2rgb(['#EC1801']),
'thomas-cook-logo-colors': hex2rgb(['#0354A6','#FFFFFF','#FEC20F']),
'thorchain-colors': hex2rgb(['#00CCFF','#33FF99','#23DCC8','#101921']),
'thrivent-financial-for-lutherans-log-colors': hex2rgb(['#DD1A32','#FFFFFF','#495966']),
'tiaa-logo-colors': hex2rgb(['#005495','#95D9F7']),
'tianjin-development-logo-colors': hex2rgb(['#E83540','#231F20']),
'tianjin-port-development-logo-colors': hex2rgb(['#08447D']),
'tianjin-port-holdings-logo-colors': hex2rgb(['#212121','#08498D','#00205A']),
'tide-logo-colors': hex2rgb(['#FFF215','#F47E40','#0068AC']),
'tikona-infinet-limited-logo-colors': hex2rgb(['#242021','#D6DF22','#25AAE2','#EB1C24']),
'tiktok-colors': hex2rgb(['#25F4EE','#FE2C55','#000000','#FFFFFF']),
'tim-hortons-color-codes': hex2rgb(['#C8102F','#FFFFFF']),
'time-warner-blue-logo-colors': hex2rgb(['#005AAE']),
'tinder-color-codes': hex2rgb(['#FD3A73','#424242']),
'titan-cement-logo-colors': hex2rgb(['#9C9D9F','#004381']),
'tivo-logo-colors': hex2rgb(['#ED1B2F','#34B228','#FFAA15','#00A9E0','#FFFFFF','#000000']),
'tj-maxx-red-logo-colors': hex2rgb(['#C40D11']),
'tobasco-logo-colors': hex2rgb(['#F33A2E','#00884D']),
'tom-logo-colors': hex2rgb(['#9BDAE9','#2E2725']),
'tommy-hilfiger-colors': hex2rgb(['#08154A','#D51635']),
'toms-shoes-colors': hex2rgb(['#A3D8F8','#000000','#FFFFFF']),
'toronto-defiant-owl-logo-colors': hex2rgb(['#C10021','#000000','#91A1AF']),
'tororo-cement-logo-colors': hex2rgb(['#036302']),
'toshiba-red-colors': hex2rgb(['#ED1B24']),
'tottenham-hotspur-f-c-logo-colors': hex2rgb(['#0A1C56','#FFFFFF']),
'toyota-colors': hex2rgb(['#F5313E','#FFFFFF']),
'toys-r-us-logo-colors': hex2rgb(['#ED145B','#F58220','#FFFFFF','#72BF44','#0061AF']),
'tpi-polene-logo-colors': hex2rgb(['#B2852E','#13007C','#FF0000']),
'tpv-technology-logo-colors': hex2rgb(['#005581']),
'tractor-supply-logo-colors': hex2rgb(['#D20000','#000000']),
'trader-joes-color-codes': hex2rgb(['#D21242']),
'transpetro-logo-colors': hex2rgb(['#FFC632','#007F3F']),
'transport-corporation-of-india-tci-colors': hex2rgb(['#FFB300','#000000']),
'travellers-logo-colors': hex2rgb(['#E61616','#000000']),
'treebo-hotels-logo-colors': hex2rgb(['#0EB550','#212121','#727171']),
'treehouse-foods-logo-colors': hex2rgb(['#000000','#007C2E','#75321F']),
'trello-logo-colors': hex2rgb(['#007AC0','#0084D1','#008FE4']),
'trent-westside-logo-colors': hex2rgb(['#0C4DA2']),
'trezor-colors': hex2rgb(['#000000']),
'tripadvisor-colors': hex2rgb(['#00AF87']),
'trivago-colors': hex2rgb(['#0088BC','#FF8B00','#D83F1F']),
'truecaller-app-icon-2017-colors': hex2rgb(['#1180FF','#2589FF','#3391FF','#4B9EFF','#5EA8FF','#71B3FF']),
'tsrtc-logo-colors': hex2rgb(['#134219','#BA9149','#EE1014','#C0F7FC','#01B037']),
'tsrtc-logo-colors-2': hex2rgb(['#134219','#BA9149','#EE1014','#C0F7FC','#01B037']),
'tst-overland-express-logo-colors': hex2rgb(['#E6403B','#004B8E']),
'tumblr-logo-colors': hex2rgb(['#35465C']),
'tvs-motor-company-logo-colors': hex2rgb(['#253C80','#DC4226']),
'twenty-first-century-fox-logo-colors': hex2rgb(['#27076E','#96979B']),
'twitch-logo-colors': hex2rgb(['#6441A4']),
'twitch-tv-color-codes': hex2rgb(['#9146FF','#FFFFFF']),
'twitter-colors': hex2rgb(['#1D9BF0']),
'ty-d-bol-logo-colors': hex2rgb(['#08559B','#0E9FE0','#FE8B18']),
'typekit-colors': hex2rgb(['#152600','#87EC00']),
'typepad-colors': hex2rgb(['#D2DE61']),
'tyson-foods-logo-colors': hex2rgb(['#001F53']),
'uber-colors': hex2rgb(['#000000','#276EF1','#3AA76D','#FFC043','#D44333','#99644C','#ED6E33','#7356BF']),
'uber-eats-logo-colors': hex2rgb(['#000000','#06C167']),
'ubuntu-logo-colors': hex2rgb(['#DD4814']),
'uc-berkeley-logo-colors': hex2rgb(['#C4820F','#FFFFFF','#003262']),
'uco-bank-logo-colors': hex2rgb(['#0044AA']),
'ucsf-logo-colors': hex2rgb(['#011B47']),
'udaya-tv-logo-colors': hex2rgb(['#7D0000','#B73300','#FEFD00','#FEB300']),
'ue-engordany-logo-colors': hex2rgb(['#010206','#3B3B3A','#A4906D','#273877','#DBE041','#DA3231']),
'ue-sant-julia-logo-colors': hex2rgb(['#231F20','#00A651','#7EAD86','#F9B926','#E0262D']),
'ue-santa-coloma-logo-colors': hex2rgb(['#020101','#464B50','#F9F09C','#F5EC54','#CD9B54','#915626']),
'ugg-logo-colors': hex2rgb(['#333333']),
'uma-colors': hex2rgb(['#FF4A4A']),
'unevoc-network-logo-colors': hex2rgb(['#002D56','#005696','#00AEEF','#8CC63F','#F8981D','#B20838']),
'unilever-blue-logo-colors': hex2rgb(['#0D009D']),
'uniqlo-colors': hex2rgb(['#ED1D24','#FFFFFF']),
'uniswap-colors': hex2rgb(['#FF007A']),
'united-2026-fifa-world-cup-bid-logo-colors': hex2rgb(['#3CAC3B','#2A398D','#E61D25','#D1D4D1','#474A4A']),
'united-airlines-logo-blue-colors': hex2rgb(['#005DAA']),
'united-breweries-group-logo-colors': hex2rgb(['#204492','#9E9FA3']),
'united-natural-foods-logo-colors': hex2rgb(['#6DB144','#645450']),
'united-parcel-service-ups-logo-colors': hex2rgb(['#FFD800','#D17B11','#452C2C','#1E0000']),
'united-states-steel-logo-colors': hex2rgb(['#0058AA']),
'united-technologies-logo-blue-colors': hex2rgb(['#1F338E']),
'unity-colors': hex2rgb(['#959595','#626262','#000000']),
'univar-logo-colors': hex2rgb(['#00ACD4','#5B5C5E']),
'universal-health-services-logo-colors': hex2rgb(['#005581']),
'universal-kids-logo-colors': hex2rgb(['#09A3AD','#FFF031']),
'university-of-cambridge-colors': hex2rgb(['#D6083B','#0072CF','#EA7125','#55A51C','#8F2BBC','#00B1C1']),
'university-of-victoria-colors': hex2rgb(['#005493','#F5AA1C','#C63527','#002754']),
'unum-group-logo-colors': hex2rgb(['#5B87A0','#005298']),
'ups-colors': hex2rgb(['#FAB80A','#301506']),
'us-army-yellow-and-black-colors': hex2rgb(['#000000','#FFCB05']),
'us-bancorp-logo-colors': hex2rgb(['#D8273F','#FFFFFF','#00438F']),
'us-foods-logo-colors': hex2rgb(['#5A881C','#D14412','#717173']),
'usaa-logo-colors': hex2rgb(['#1A3258']),
'usps-colors': hex2rgb(['#15569C','#ED192D','#FFFFFF']),
'usps-web-site-colors': hex2rgb(['#333465','#FFFFFF','#F7F7F7','#EDEDED','#D8D8D8','#E81921']),
'vadilal-logo-colors': hex2rgb(['#FFDD02','#EC1C24','#FFFFFF']),
'valero-energy-logo-colors': hex2rgb(['#006C87','#FFB900']),
'van-wijngen-international-logo-colors': hex2rgb(['#101244','#0098DC']),
'vancouver-titans-owl-logo-colors': hex2rgb(['#09226B','#FFFFFF','#2FB228']),
'vanish-logo-colors': hex2rgb(['#E22393','#001A71','#00BAEC','#FBEC40','#E6000B']),
'venmo-colors': hex2rgb(['#008CFF']),
'verge-colors': hex2rgb(['#4CC2F1','#000000']),
'veritiv-logo-greens-colors': hex2rgb(['#1D5632','#007934']),
'verizon-red-colors': hex2rgb(['#CF0000']),
'verizon-wireless-color-codes': hex2rgb(['#D52B1E','#000000']),
'viacom-18-logo-colors': hex2rgb(['#2E368F','#CC0000']),
'viastore-systems-logo-colors': hex2rgb(['#00386A','#E30613','#A3130E','#6D1002']),
'viber-colors': hex2rgb(['#7360F2','#FFFFFF']),
'vicat-logo-colors': hex2rgb(['#004685']),
'victoria-plum-logo-colors': hex2rgb(['#4A1539']),
'vileda-logo-colors': hex2rgb(['#DA0017','#A0C62C','#00B1EB']),
'villarreal-cf-logo-colors': hex2rgb(['#005187','#FFE667','#000000','#E72B01']),
'vine-logo-colors': hex2rgb(['#00B488']),
'vip-industries-logo-colors': hex2rgb(['#ED1C24']),
'virgin-hyperloop-colors': hex2rgb(['#DE0A06','#B0A99F']),
'visa-colors': hex2rgb(['#1434CB']),
'vishal-logo-colors': hex2rgb(['#354880','#C92F6D']),
'vistaprint-colors': hex2rgb(['#FCE92D','#F19914','#DD3884','#C60062','#3A8BDA','#0456A2']),
'visual-ly-logo-colors': hex2rgb(['#10B190','#FF6060','#F9D889','#F5B13B','#F89747']),
'vivo-colors': hex2rgb(['#00BFFF']),
'vivo-logo-blue-colors': hex2rgb(['#0072B8']),
'vodafone-logo-colors': hex2rgb(['#E60000','#FFFFFF']),
'volusion-logo-colors': hex2rgb(['#8759F2','#00D4E6','#FF3E80','#FFC300']),
'volvo-logo-colors': hex2rgb(['#073498']),
'votorantim-cimentos-logo-colors': hex2rgb(['#7BBFE3','#184478','#707270']),
'voya-financial-logo-colors': hex2rgb(['#F36621','#F99E1C','#FDBA11']),
'vue-js-logo-colors': hex2rgb(['#34495E','#41B883']),
'w-r-berkley-logo-colors': hex2rgb(['#004812']),
'w-w-grainger-logo-colors': hex2rgb(['#BE2122']),
'w3schools-website-colors': hex2rgb(['#36AF57','#555555','#CCCCCC','#F1F1F1','#3A3A3A']),
'walgreens-boots-alliance-logo-colors': hex2rgb(['#1C2262','#8FABDB','#FFFFFF','#8EC83E','#5AADE1']),
'walgreens-color-codes': hex2rgb(['#E63425']),
'walmart-colors': hex2rgb(['#0071CE','#FCB61A']),
'walt-disney-colors': hex2rgb(['#000000']),
'wandera-logo-colors': hex2rgb(['#36A12E','#FFFFFF','#191414']),
'warwick-hotels-and-resorts-logo-colors': hex2rgb(['#937F36','#242021']),
'washington-justice-owl-logo-colors': hex2rgb(['#990034','#FFFFFF','#003768']),
'washington-redskins-team-colors': hex2rgb(['#5C2B2E','#FFB700']),
'waste-management-logo-colors': hex2rgb(['#026937','#EDAA00']),
'wave-apps-colors': hex2rgb(['#1C2D37','#4EC7C4','#00959F','#3B9BCC']),
'wayfair-colors': hex2rgb(['#7F187F','#D57DEA','#F8CF1C','#C6D636','#82D170']),
'webpack-logo-colors': hex2rgb(['#8ED5FA','#1C78C0']),
'websults-logo-colors': hex2rgb(['#2A5668','#FFCF38']),
'wec-energy-group-logo-colors': hex2rgb(['#0088CE','#5F5F5F']),
'wechat-logo-colors': hex2rgb(['#7BB32E']),
'weebly-logo-colors': hex2rgb(['#0099D6']),
'wellcare-health-plans-logo-blue-colors': hex2rgb(['#1B75BB']),
'wells-fargo-championship-golf-logo-colors': hex2rgb(['#B7132C','#B89558']),
'wells-fargo-logo-colors': hex2rgb(['#CD1409','#FFFF00']),
'wendys-color-codes': hex2rgb(['#CF202E','#A51D36','#00A0DD','#453635','#F4D3D6','#FFFFFF']),
'wendys-supa-sundaes-logo-colors': hex2rgb(['#EF3E6C','#F4A2C6','#FFFFFF']),
'wescale-colors': hex2rgb(['#09AA9D','#6A8AAA','#EFEFEF','#212E3E','#000000']),
'wesco-international-logo-blue-colors': hex2rgb(['#004684']),
'west-coast-eagles-logo-colors-2': hex2rgb(['#002D88','#FFFFFF','#F3AB00']),
'western-bulldogs-logo-colors': hex2rgb(['#1C2E71','#1A529E','#FFFFFF','#BE0027']),
'western-digital-logo-blue-colors': hex2rgb(['#00529F']),
'western-refining-logo-colors': hex2rgb(['#000000','#FED22B','#908F91']),
'westrock-logo-colors': hex2rgb(['#004B87','#0085CA','#FF8200']),
'wests-tigers-logo-colors': hex2rgb(['#F1493C','#F68C1A','#FFDE02','#FFFFFF','#000000']),
'weyerhaeuser-logo-colors': hex2rgb(['#008147','#000000']),
'whataburger-color-codes': hex2rgb(['#FF770F']),
'whatsapp-color-codes': hex2rgb(['#5FFC7B','#28D146']),
'whirlpool-logo-colors': hex2rgb(['#EFB200','#000000']),
'white-castle-color-codes': hex2rgb(['#011375','#FFFFFF','#FBA301']),
'white-spot-logo-colors': hex2rgb(['#92192F','#D8CC25','#FFFFFF','#07656A']),
'whole-foods-color-codes': hex2rgb(['#006F46']),
'wholesale-club-logo-colors': hex2rgb(['#0166B1','#FFF200','#E41B23']),
'wholesale-club-logo-colors-2': hex2rgb(['#0166B1','#FFF200','#E41B23']),
'wikihow-logo-colors': hex2rgb(['#445046','#93B873']),
'wikimapia-logo-colors': hex2rgb(['#CC0000']),
'wikimedia-commons-logo-colors': hex2rgb(['#970000','#006499','#666666']),
'wikinews-logo-colors': hex2rgb(['#2284D9','#DEEAFF','#E7F1FF','#B7CEE2','#8C8C8C','#595959']),
'wikipedia-logo-colors': hex2rgb(['#3D393A','#6B6B6B','#ACABAD','#F8F8F8','#EEEEEF']),
'wikitravel-logo-colors': hex2rgb(['#3888B6','#71A6C1','#437C9B','#1B4157']),
'wildlife-conservation-society-wcs-colors': hex2rgb(['#04AC9E','#039659','#36AD47','#086E3D','#0F70B4','#030303']),
'williams-logo-colors': hex2rgb(['#0066CA','#010101']),
'windex-logo-colors': hex2rgb(['#EE2E24','#A80505','#083A81']),
'windstream-color-codes': hex2rgb(['#7FCC28','#000000']),
'wingstop-logo-colors': hex2rgb(['#146A34']),
'wingstreet-logo-colors': hex2rgb(['#9E3323','#FEBA1C','#231F20']),
'winrar-colors': hex2rgb(['#184D00','#008857','#00559F','#920159','#4F0000']),
'winston-cigarettes-colors': hex2rgb(['#950316','#C0AC52']),
'wirex-colors': hex2rgb(['#053F33']),
'wish-colors': hex2rgb(['#2EB7EB']),
'wix-com-ltd-logo-colors': hex2rgb(['#FBBD71','#000000']),
'wnba-on-espn-logo-colors': hex2rgb(['#050707','#4C4C4D','#EFE3C6','#F57B20']),
'woolite-logo-colors': hex2rgb(['#202F66','#0292CE']),
'word-color-codes': hex2rgb(['#1B5EBE','#41A5EE','#2B7CD3','#103F91','#FFFFFF']),
'wordpress-logo-colors': hex2rgb(['#444140','#00749C']),
'woriginal-colors': hex2rgb(['#ABA0F4','#9CADF4','#B1A2D2','#B193E9','#9E9DDC']),
'world-bank-group-colors': hex2rgb(['#002244','#009FDA','#FFFFFF','#000000']),
'world-health-organization-who-logo-colors': hex2rgb(['#009CDE']),
'world-wide-web-consortium-w3c-logo-colors-2': hex2rgb(['#005A9C','#000000']),
'wrigleys-doublemint-gum-colors': hex2rgb(['#0D2D15','#BDDE34','#DF1208']),
'wrigleys-juicy-fruit-gum-colors': hex2rgb(['#FFCA02','#FBD818','#D63246','#FFE58E','#4347A0','#04BBEC']),
'wrigleys-spearmint-gum-colors': hex2rgb(['#AA1731','#FFFFFF','#005442']),
'wufoo-website-colors': hex2rgb(['#8580CA','#8C87CD','#FFFFFF','#FFDF8F','#61E064','#B8E986']),
'xampp-logo-orange-colors': hex2rgb(['#FB7A24']),
'xbox-color-codes': hex2rgb(['#000000']),
'xbox-old-logo-colors': hex2rgb(['#7EB900']),
'xcel-energy-logo-colors': hex2rgb(['#ED2128','#231F20']),
'xerox-corporation-logo-colors': hex2rgb(['#D92231']),
'xfinity-logo-colors': hex2rgb(['#C8001D']),
'xpo-logistics-logo-colors': hex2rgb(['#CC0000','#000000']),
'xubuntu-linux-logo-colors': hex2rgb(['#333333','#FFFFFF','#0040AD']),
'yahoo-logo-colors': hex2rgb(['#410093']),
'yandex-colors': hex2rgb(['#FFCC00','#FF0000','#000000']),
'yanke-group-logo-colors': hex2rgb(['#054F7D','#282425']),
'yashoda-hospitals-logo-colors': hex2rgb(['#F58634','#34316E']),
'yellow-cab-pizza-logo-colors': hex2rgb(['#FDB813','#000000']),
'yellow-post-it-notes-colors': hex2rgb(['#FFFF99']),
'yelp-colors': hex2rgb(['#FF1A1A','#000000','#FFFFFF']),
'yeoman-logo-colors': hex2rgb(['#050505','#DD002A','#FFB000','#F4CF8C','#C98C28','#4F1907']),
'yii-framework-logo-colors': hex2rgb(['#D8582B','#16A314','#3B6FBA']),
'yogen-fruz-colors': hex2rgb(['#0297D9','#F28CB4']),
'yola-logo-colors': hex2rgb(['#691222','#FFFFFF','#E7004F']),
'you-broadband-india-limited-logo-colors': hex2rgb(['#E30713','#004C8E','#063F14']),
'youtube-color-codes': hex2rgb(['#FF0000','#282828']),
'youtube-new-red-colors': hex2rgb(['#FF0000']),
'yum-brands-logo-red-colors': hex2rgb(['#ED1C24']),
'yum-china-holdings-logo-red-white-colors': hex2rgb(['#ED1C24','#FFFFFF']),
'zam-zam-logo-colors': hex2rgb(['#E51C29','#EF8247','#FDC918','#A5C73F','#22A753','#8CD3F2']),
'zapier-colors': hex2rgb(['#FF4A00','#FD7622','#FFC43E','#5F6C72','#499DF3','#13D0AB']),
'zapper-logo-colors': hex2rgb(['#3E80C0']),
'zappos-color-codes': hex2rgb(['#000000','#5D80A8']),
'zcash-colors': hex2rgb(['#231F20','#F4B728']),
'zee-24-taas-logo-colors': hex2rgb(['#F6A537','#EF4924']),
'zee-anmol-logo-colors': hex2rgb(['#FF2E62']),
'zee-magic-logo-colors': hex2rgb(['#1977BD','#F5E400','#10110C']),
'zee-news-logo-colors': hex2rgb(['#DA2129']),
'zexel-logo-colors': hex2rgb(['#567DBB','#FF350D']),
'ziggo-logo-colors': hex2rgb(['#F48D01']),
'zilliqa-colors': hex2rgb(['#242828','#29CCC4','#299197','#036F7D']),
'zimmer-biomet-holdings-logo-colors': hex2rgb(['#009FDF','#333333']),
'zions-bancorporation-logo-colors': hex2rgb(['#54534A']),
'zipcar-logo-colors': hex2rgb(['#4FA601','#FFFFFF','#4D4D59']),
'zipline-international-logo-colors': hex2rgb(['#E73C3E']),
'zira-fk-logo-colors': hex2rgb(['#001366','#0016EB','#67C7FF','#FFFFFF','#C4E6FD']),
'zoho-corporation-logo-colors': hex2rgb(['#CE2232','#219E4A','#0974B0','#FFE004']),
'zomato-logo-colors': hex2rgb(['#CB202D','#2D2D2D']),
'zoom-colors': hex2rgb(['#2D8CFF']),
'zoom-logo-colors': hex2rgb(['#2D8CFF']),
'zoomcar-logo-colors': hex2rgb(['#79B641','#6E6F71']),
'zscaler-logo-colors': hex2rgb(['#009CDA']),
}
